;;; company-emoji-list.el --- Unicode emoji as propertized strings

;; Copyright (C) 2023 Alex Dunn

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;;; Code:

(defun company-emoji-list-create ()
  "Return the propertized list of emoji."
;; See
;; https://www.gnu.org/software/emacs/manual/html_node/elisp/Text-Props-and-Strings.html
;; for the syntax.
  (list
    #(":+1:" 0 1 (:unicode "👍"))
    #(":-1:" 0 1 (:unicode "👎"))
    #(":100:" 0 1 (:unicode "💯"))
    #(":1234:" 0 1 (:unicode "🔢"))
    #(":1st_place_medal:" 0 1 (:unicode "🥇"))
    #(":2nd_place_medal:" 0 1 (:unicode "🥈"))
    #(":3rd_place_medal:" 0 1 (:unicode "🥉"))
    #(":8ball:" 0 1 (:unicode "🎱"))
    #(":I am a witness:" 0 1 (:unicode "👁‍🗨"))
    #(":a:" 0 1 (:unicode "🅰️"))
    #(":ab:" 0 1 (:unicode "🆎"))
    #(":abacus:" 0 1 (:unicode "🧮"))
    #(":abc:" 0 1 (:unicode "🔤"))
    #(":abcd:" 0 1 (:unicode "🔡"))
    #(":accept:" 0 1 (:unicode "🉑"))
    #(":accordion:" 0 1 (:unicode "🪗"))
    #(":adhesive_bandage:" 0 1 (:unicode "🩹"))
    #(":adult:" 0 1 (:unicode "🧑"))
    #(":aerial_tramway:" 0 1 (:unicode "🚡"))
    #(":afghanistan:" 0 1 (:unicode "🇦🇫"))
    #(":airplane:" 0 1 (:unicode "✈️"))
    #(":aland_islands:" 0 1 (:unicode "🇦🇽"))
    #(":alarm_clock:" 0 1 (:unicode "⏰"))
    #(":albania:" 0 1 (:unicode "🇦🇱"))
    #(":alembic:" 0 1 (:unicode "⚗️"))
    #(":algeria:" 0 1 (:unicode "🇩🇿"))
    #(":alien:" 0 1 (:unicode "👽"))
    #(":ambulance:" 0 1 (:unicode "🚑"))
    #(":american_samoa:" 0 1 (:unicode "🇦🇸"))
    #(":amphora:" 0 1 (:unicode "🏺"))
    #(":anatomical_heart:" 0 1 (:unicode "🫀"))
    #(":anchor:" 0 1 (:unicode "⚓"))
    #(":andorra:" 0 1 (:unicode "🇦🇩"))
    #(":angel:" 0 1 (:unicode "👼"))
    #(":anger:" 0 1 (:unicode "💢"))
    #(":angola:" 0 1 (:unicode "🇦🇴"))
    #(":angry:" 0 1 (:unicode "😠"))
    #(":anguilla:" 0 1 (:unicode "🇦🇮"))
    #(":anguished:" 0 1 (:unicode "😧"))
    #(":ant:" 0 1 (:unicode "🐜"))
    #(":antarctica:" 0 1 (:unicode "🇦🇶"))
    #(":antigua_barbuda:" 0 1 (:unicode "🇦🇬"))
    #(":apple:" 0 1 (:unicode "🍎"))
    #(":aquarius:" 0 1 (:unicode "♒"))
    #(":argentina:" 0 1 (:unicode "🇦🇷"))
    #(":aries:" 0 1 (:unicode "♈"))
    #(":armenia:" 0 1 (:unicode "🇦🇲"))
    #(":arrow_backward:" 0 1 (:unicode "◀️"))
    #(":arrow_double_down:" 0 1 (:unicode "⏬"))
    #(":arrow_double_up:" 0 1 (:unicode "⏫"))
    #(":arrow_down:" 0 1 (:unicode "⬇️"))
    #(":arrow_down_small:" 0 1 (:unicode "🔽"))
    #(":arrow_forward:" 0 1 (:unicode "▶️"))
    #(":arrow_heading_down:" 0 1 (:unicode "⤵️"))
    #(":arrow_heading_up:" 0 1 (:unicode "⤴️"))
    #(":arrow_left:" 0 1 (:unicode "⬅️"))
    #(":arrow_lower_left:" 0 1 (:unicode "↙️"))
    #(":arrow_lower_right:" 0 1 (:unicode "↘️"))
    #(":arrow_right:" 0 1 (:unicode "➡️"))
    #(":arrow_right_hook:" 0 1 (:unicode "↪️"))
    #(":arrow_up:" 0 1 (:unicode "⬆️"))
    #(":arrow_up_down:" 0 1 (:unicode "↕️"))
    #(":arrow_up_small:" 0 1 (:unicode "🔼"))
    #(":arrow_upper_left:" 0 1 (:unicode "↖️"))
    #(":arrow_upper_right:" 0 1 (:unicode "↗️"))
    #(":arrows_clockwise:" 0 1 (:unicode "🔃"))
    #(":arrows_counterclockwise:" 0 1 (:unicode "🔄"))
    #(":art:" 0 1 (:unicode "🎨"))
    #(":articulated_lorry:" 0 1 (:unicode "🚛"))
    #(":artificial_satellite:" 0 1 (:unicode "🛰️"))
    #(":artist:" 0 1 (:unicode "🧑‍🎨"))
    #(":aruba:" 0 1 (:unicode "🇦🇼"))
    #(":ascension_island:" 0 1 (:unicode "🇦🇨"))
    #(":asterisk:" 0 1 (:unicode "*️⃣"))
    #(":astonished:" 0 1 (:unicode "😲"))
    #(":astronaut:" 0 1 (:unicode "🧑‍🚀"))
    #(":athletic_shoe:" 0 1 (:unicode "👟"))
    #(":atm:" 0 1 (:unicode "🏧"))
    #(":atom_symbol:" 0 1 (:unicode "⚛️"))
    #(":australia:" 0 1 (:unicode "🇦🇺"))
    #(":austria:" 0 1 (:unicode "🇦🇹"))
    #(":auto_rickshaw:" 0 1 (:unicode "🛺"))
    #(":avocado:" 0 1 (:unicode "🥑"))
    #(":axe:" 0 1 (:unicode "🪓"))
    #(":azerbaijan:" 0 1 (:unicode "🇦🇿"))
    #(":b:" 0 1 (:unicode "🅱️"))
    #(":baby:" 0 1 (:unicode "👶"))
    #(":baby_bottle:" 0 1 (:unicode "🍼"))
    #(":baby_chick:" 0 1 (:unicode "🐤"))
    #(":baby_symbol:" 0 1 (:unicode "🚼"))
    #(":back:" 0 1 (:unicode "🔙"))
    #(":bacon:" 0 1 (:unicode "🥓"))
    #(":badger:" 0 1 (:unicode "🦡"))
    #(":badminton:" 0 1 (:unicode "🏸"))
    #(":bagel:" 0 1 (:unicode "🥯"))
    #(":baggage_claim:" 0 1 (:unicode "🛄"))
    #(":baguette_bread:" 0 1 (:unicode "🥖"))
    #(":bahamas:" 0 1 (:unicode "🇧🇸"))
    #(":bahrain:" 0 1 (:unicode "🇧🇭"))
    #(":balance_scale:" 0 1 (:unicode "⚖️"))
    #(":bald_man:" 0 1 (:unicode "👨‍🦲"))
    #(":bald_woman:" 0 1 (:unicode "👩‍🦲"))
    #(":ballet_shoes:" 0 1 (:unicode "🩰"))
    #(":balloon:" 0 1 (:unicode "🎈"))
    #(":ballot_box:" 0 1 (:unicode "🗳️"))
    #(":ballot_box_with_check:" 0 1 (:unicode "☑️"))
    #(":bamboo:" 0 1 (:unicode "🎍"))
    #(":banana:" 0 1 (:unicode "🍌"))
    #(":bangbang:" 0 1 (:unicode "‼️"))
    #(":bangladesh:" 0 1 (:unicode "🇧🇩"))
    #(":banjo:" 0 1 (:unicode "🪕"))
    #(":bank:" 0 1 (:unicode "🏦"))
    #(":bar_chart:" 0 1 (:unicode "📊"))
    #(":barbados:" 0 1 (:unicode "🇧🇧"))
    #(":barber:" 0 1 (:unicode "💈"))
    #(":baseball:" 0 1 (:unicode "⚾"))
    #(":basket:" 0 1 (:unicode "🧺"))
    #(":basketball:" 0 1 (:unicode "🏀"))
    #(":bat:" 0 1 (:unicode "🦇"))
    #(":bath:" 0 1 (:unicode "🛀"))
    #(":bathtub:" 0 1 (:unicode "🛁"))
    #(":battery:" 0 1 (:unicode "🔋"))
    #(":beach_umbrella:" 0 1 (:unicode "🏖️"))
    #(":beans:" 0 1 (:unicode "🫘"))
    #(":bear:" 0 1 (:unicode "🐻"))
    #(":bearded_person:" 0 1 (:unicode "🧔"))
    #(":beaver:" 0 1 (:unicode "🦫"))
    #(":bed:" 0 1 (:unicode "🛏️"))
    #(":bee:" 0 1 (:unicode "🐝"))
    #(":beer:" 0 1 (:unicode "🍺"))
    #(":beers:" 0 1 (:unicode "🍻"))
    #(":beetle:" 0 1 (:unicode "🪲"))
    #(":beginner:" 0 1 (:unicode "🔰"))
    #(":belarus:" 0 1 (:unicode "🇧🇾"))
    #(":belgium:" 0 1 (:unicode "🇧🇪"))
    #(":belize:" 0 1 (:unicode "🇧🇿"))
    #(":bell:" 0 1 (:unicode "🔔"))
    #(":bell_pepper:" 0 1 (:unicode "🫑"))
    #(":bellhop_bell:" 0 1 (:unicode "🛎️"))
    #(":benin:" 0 1 (:unicode "🇧🇯"))
    #(":bento:" 0 1 (:unicode "🍱"))
    #(":bermuda:" 0 1 (:unicode "🇧🇲"))
    #(":beverage_box:" 0 1 (:unicode "🧃"))
    #(":bhutan:" 0 1 (:unicode "🇧🇹"))
    #(":bicyclist:" 0 1 (:unicode "🚴"))
    #(":bike:" 0 1 (:unicode "🚲"))
    #(":biking_man:" 0 1 (:unicode "🚴‍♂️"))
    #(":biking_woman:" 0 1 (:unicode "🚴‍♀️"))
    #(":bikini:" 0 1 (:unicode "👙"))
    #(":billed_cap:" 0 1 (:unicode "🧢"))
    #(":biohazard:" 0 1 (:unicode "☣️"))
    #(":bird:" 0 1 (:unicode "🐦"))
    #(":birthday:" 0 1 (:unicode "🎂"))
    #(":bison:" 0 1 (:unicode "🦬"))
    #(":biting_lip:" 0 1 (:unicode "🫦"))
    #(":black_bird:" 0 1 (:unicode "🐦‍⬛"))
    #(":black_cat:" 0 1 (:unicode "🐈‍⬛"))
    #(":black_circle:" 0 1 (:unicode "⚫"))
    #(":black_flag:" 0 1 (:unicode "🏴"))
    #(":black_heart:" 0 1 (:unicode "🖤"))
    #(":black_joker:" 0 1 (:unicode "🃏"))
    #(":black_large_square:" 0 1 (:unicode "⬛"))
    #(":black_medium_small_square:" 0 1 (:unicode "◾"))
    #(":black_medium_square:" 0 1 (:unicode "◼️"))
    #(":black_nib:" 0 1 (:unicode "✒️"))
    #(":black_small_square:" 0 1 (:unicode "▪️"))
    #(":black_square_button:" 0 1 (:unicode "🔲"))
    #(":blond_haired_man:" 0 1 (:unicode "👱‍♂️"))
    #(":blond_haired_person:" 0 1 (:unicode "👱"))
    #(":blond_haired_woman:" 0 1 (:unicode "👱‍♀️"))
    #(":blossom:" 0 1 (:unicode "🌼"))
    #(":blowfish:" 0 1 (:unicode "🐡"))
    #(":blue_book:" 0 1 (:unicode "📘"))
    #(":blue_car:" 0 1 (:unicode "🚙"))
    #(":blue_heart:" 0 1 (:unicode "💙"))
    #(":blue_square:" 0 1 (:unicode "🟦"))
    #(":blueberries:" 0 1 (:unicode "🫐"))
    #(":blush:" 0 1 (:unicode "😊"))
    #(":boar:" 0 1 (:unicode "🐗"))
    #(":boat:" 0 1 (:unicode "⛵"))
    #(":bolivia:" 0 1 (:unicode "🇧🇴"))
    #(":bomb:" 0 1 (:unicode "💣"))
    #(":bone:" 0 1 (:unicode "🦴"))
    #(":book:" 0 1 (:unicode "📖"))
    #(":bookmark:" 0 1 (:unicode "🔖"))
    #(":bookmark_tabs:" 0 1 (:unicode "📑"))
    #(":books:" 0 1 (:unicode "📚"))
    #(":boom:" 0 1 (:unicode "💥"))
    #(":boomerang:" 0 1 (:unicode "🪃"))
    #(":boot:" 0 1 (:unicode "👢"))
    #(":bosnia_herzegovina:" 0 1 (:unicode "🇧🇦"))
    #(":botswana:" 0 1 (:unicode "🇧🇼"))
    #(":bouncing_ball_man:" 0 1 (:unicode "⛹️‍♂️"))
    #(":bouncing_ball_person:" 0 1 (:unicode "⛹️"))
    #(":bouncing_ball_woman:" 0 1 (:unicode "⛹️‍♀️"))
    #(":bouquet:" 0 1 (:unicode "💐"))
    #(":bouvet_island:" 0 1 (:unicode "🇧🇻"))
    #(":bow:" 0 1 (:unicode "🙇"))
    #(":bow_and_arrow:" 0 1 (:unicode "🏹"))
    #(":bowing_man:" 0 1 (:unicode "🙇‍♂️"))
    #(":bowing_woman:" 0 1 (:unicode "🙇‍♀️"))
    #(":bowl_with_spoon:" 0 1 (:unicode "🥣"))
    #(":bowling:" 0 1 (:unicode "🎳"))
    #(":boxing_glove:" 0 1 (:unicode "🥊"))
    #(":boy:" 0 1 (:unicode "👦"))
    #(":brain:" 0 1 (:unicode "🧠"))
    #(":brazil:" 0 1 (:unicode "🇧🇷"))
    #(":bread:" 0 1 (:unicode "🍞"))
    #(":breast_feeding:" 0 1 (:unicode "🤱"))
    #(":bricks:" 0 1 (:unicode "🧱"))
    #(":bridge_at_night:" 0 1 (:unicode "🌉"))
    #(":briefcase:" 0 1 (:unicode "💼"))
    #(":british_indian_ocean_territory:" 0 1 (:unicode "🇮🇴"))
    #(":british_virgin_islands:" 0 1 (:unicode "🇻🇬"))
    #(":broccoli:" 0 1 (:unicode "🥦"))
    #(":broken_heart:" 0 1 (:unicode "💔"))
    #(":broom:" 0 1 (:unicode "🧹"))
    #(":brown_circle:" 0 1 (:unicode "🟤"))
    #(":brown_heart:" 0 1 (:unicode "🤎"))
    #(":brown_square:" 0 1 (:unicode "🟫"))
    #(":brunei:" 0 1 (:unicode "🇧🇳"))
    #(":bubble_tea:" 0 1 (:unicode "🧋"))
    #(":bubbles:" 0 1 (:unicode "🫧"))
    #(":bucket:" 0 1 (:unicode "🪣"))
    #(":bug:" 0 1 (:unicode "🐛"))
    #(":building_construction:" 0 1 (:unicode "🏗️"))
    #(":bulb:" 0 1 (:unicode "💡"))
    #(":bulgaria:" 0 1 (:unicode "🇧🇬"))
    #(":bullettrain_front:" 0 1 (:unicode "🚅"))
    #(":bullettrain_side:" 0 1 (:unicode "🚄"))
    #(":burkina_faso:" 0 1 (:unicode "🇧🇫"))
    #(":burrito:" 0 1 (:unicode "🌯"))
    #(":burundi:" 0 1 (:unicode "🇧🇮"))
    #(":bus:" 0 1 (:unicode "🚌"))
    #(":business_suit_levitating:" 0 1 (:unicode "🕴️"))
    #(":busstop:" 0 1 (:unicode "🚏"))
    #(":bust_in_silhouette:" 0 1 (:unicode "👤"))
    #(":busts_in_silhouette:" 0 1 (:unicode "👥"))
    #(":butter:" 0 1 (:unicode "🧈"))
    #(":butterfly:" 0 1 (:unicode "🦋"))
    #(":cactus:" 0 1 (:unicode "🌵"))
    #(":cake:" 0 1 (:unicode "🍰"))
    #(":calendar:" 0 1 (:unicode "📆"))
    #(":call_me_hand:" 0 1 (:unicode "🤙"))
    #(":calling:" 0 1 (:unicode "📲"))
    #(":cambodia:" 0 1 (:unicode "🇰🇭"))
    #(":camel:" 0 1 (:unicode "🐫"))
    #(":camera:" 0 1 (:unicode "📷"))
    #(":camera_flash:" 0 1 (:unicode "📸"))
    #(":cameroon:" 0 1 (:unicode "🇨🇲"))
    #(":camping:" 0 1 (:unicode "🏕️"))
    #(":canada:" 0 1 (:unicode "🇨🇦"))
    #(":canary_islands:" 0 1 (:unicode "🇮🇨"))
    #(":cancer:" 0 1 (:unicode "♋"))
    #(":candle:" 0 1 (:unicode "🕯️"))
    #(":candy:" 0 1 (:unicode "🍬"))
    #(":canned_food:" 0 1 (:unicode "🥫"))
    #(":canoe:" 0 1 (:unicode "🛶"))
    #(":cape_verde:" 0 1 (:unicode "🇨🇻"))
    #(":capital_abcd:" 0 1 (:unicode "🔠"))
    #(":capricorn:" 0 1 (:unicode "♑"))
    #(":car:" 0 1 (:unicode "🚗"))
    #(":card_file_box:" 0 1 (:unicode "🗃️"))
    #(":card_index:" 0 1 (:unicode "📇"))
    #(":card_index_dividers:" 0 1 (:unicode "🗂️"))
    #(":caribbean_netherlands:" 0 1 (:unicode "🇧🇶"))
    #(":carousel_horse:" 0 1 (:unicode "🎠"))
    #(":carpentry_saw:" 0 1 (:unicode "🪚"))
    #(":carrot:" 0 1 (:unicode "🥕"))
    #(":cartwheeling:" 0 1 (:unicode "🤸"))
    #(":cat:" 0 1 (:unicode "🐱"))
    #(":cat2:" 0 1 (:unicode "🐈"))
    #(":cayman_islands:" 0 1 (:unicode "🇰🇾"))
    #(":cd:" 0 1 (:unicode "💿"))
    #(":central_african_republic:" 0 1 (:unicode "🇨🇫"))
    #(":ceuta_melilla:" 0 1 (:unicode "🇪🇦"))
    #(":chad:" 0 1 (:unicode "🇹🇩"))
    #(":chains:" 0 1 (:unicode "⛓️"))
    #(":chair:" 0 1 (:unicode "🪑"))
    #(":champagne:" 0 1 (:unicode "🍾"))
    #(":chart:" 0 1 (:unicode "💹"))
    #(":chart_with_downwards_trend:" 0 1 (:unicode "📉"))
    #(":chart_with_upwards_trend:" 0 1 (:unicode "📈"))
    #(":checkered_flag:" 0 1 (:unicode "🏁"))
    #(":cheese:" 0 1 (:unicode "🧀"))
    #(":cherries:" 0 1 (:unicode "🍒"))
    #(":cherry_blossom:" 0 1 (:unicode "🌸"))
    #(":chess_pawn:" 0 1 (:unicode "♟️"))
    #(":chestnut:" 0 1 (:unicode "🌰"))
    #(":chicken:" 0 1 (:unicode "🐔"))
    #(":child:" 0 1 (:unicode "🧒"))
    #(":children_crossing:" 0 1 (:unicode "🚸"))
    #(":chile:" 0 1 (:unicode "🇨🇱"))
    #(":chipmunk:" 0 1 (:unicode "🐿️"))
    #(":chocolate_bar:" 0 1 (:unicode "🍫"))
    #(":chopsticks:" 0 1 (:unicode "🥢"))
    #(":christmas_island:" 0 1 (:unicode "🇨🇽"))
    #(":christmas_tree:" 0 1 (:unicode "🎄"))
    #(":church:" 0 1 (:unicode "⛪"))
    #(":cinema:" 0 1 (:unicode "🎦"))
    #(":circus_tent:" 0 1 (:unicode "🎪"))
    #(":city_sunrise:" 0 1 (:unicode "🌇"))
    #(":city_sunset:" 0 1 (:unicode "🌆"))
    #(":cityscape:" 0 1 (:unicode "🏙️"))
    #(":cl:" 0 1 (:unicode "🆑"))
    #(":clamp:" 0 1 (:unicode "🗜️"))
    #(":clap:" 0 1 (:unicode "👏"))
    #(":clapper:" 0 1 (:unicode "🎬"))
    #(":classical_building:" 0 1 (:unicode "🏛️"))
    #(":climbing:" 0 1 (:unicode "🧗"))
    #(":climbing_man:" 0 1 (:unicode "🧗‍♂️"))
    #(":climbing_woman:" 0 1 (:unicode "🧗‍♀️"))
    #(":clinking_glasses:" 0 1 (:unicode "🥂"))
    #(":clipboard:" 0 1 (:unicode "📋"))
    #(":clipperton_island:" 0 1 (:unicode "🇨🇵"))
    #(":clock1:" 0 1 (:unicode "🕐"))
    #(":clock10:" 0 1 (:unicode "🕙"))
    #(":clock1030:" 0 1 (:unicode "🕥"))
    #(":clock11:" 0 1 (:unicode "🕚"))
    #(":clock1130:" 0 1 (:unicode "🕦"))
    #(":clock12:" 0 1 (:unicode "🕛"))
    #(":clock1230:" 0 1 (:unicode "🕧"))
    #(":clock130:" 0 1 (:unicode "🕜"))
    #(":clock2:" 0 1 (:unicode "🕑"))
    #(":clock230:" 0 1 (:unicode "🕝"))
    #(":clock3:" 0 1 (:unicode "🕒"))
    #(":clock330:" 0 1 (:unicode "🕞"))
    #(":clock4:" 0 1 (:unicode "🕓"))
    #(":clock430:" 0 1 (:unicode "🕟"))
    #(":clock5:" 0 1 (:unicode "🕔"))
    #(":clock530:" 0 1 (:unicode "🕠"))
    #(":clock6:" 0 1 (:unicode "🕕"))
    #(":clock630:" 0 1 (:unicode "🕡"))
    #(":clock7:" 0 1 (:unicode "🕖"))
    #(":clock730:" 0 1 (:unicode "🕢"))
    #(":clock8:" 0 1 (:unicode "🕗"))
    #(":clock830:" 0 1 (:unicode "🕣"))
    #(":clock9:" 0 1 (:unicode "🕘"))
    #(":clock930:" 0 1 (:unicode "🕤"))
    #(":closed_book:" 0 1 (:unicode "📕"))
    #(":closed_lock_with_key:" 0 1 (:unicode "🔐"))
    #(":closed_umbrella:" 0 1 (:unicode "🌂"))
    #(":cloud:" 0 1 (:unicode "☁️"))
    #(":cloud_with_lightning:" 0 1 (:unicode "🌩️"))
    #(":cloud_with_lightning_and_rain:" 0 1 (:unicode "⛈️"))
    #(":cloud_with_rain:" 0 1 (:unicode "🌧️"))
    #(":cloud_with_snow:" 0 1 (:unicode "🌨️"))
    #(":clown_face:" 0 1 (:unicode "🤡"))
    #(":clubs:" 0 1 (:unicode "♣️"))
    #(":cn:" 0 1 (:unicode "🇨🇳"))
    #(":coat:" 0 1 (:unicode "🧥"))
    #(":cockroach:" 0 1 (:unicode "🪳"))
    #(":cocktail:" 0 1 (:unicode "🍸"))
    #(":coconut:" 0 1 (:unicode "🥥"))
    #(":cocos_islands:" 0 1 (:unicode "🇨🇨"))
    #(":coffee:" 0 1 (:unicode "☕"))
    #(":coffin:" 0 1 (:unicode "⚰️"))
    #(":coin:" 0 1 (:unicode "🪙"))
    #(":cold_face:" 0 1 (:unicode "🥶"))
    #(":cold_sweat:" 0 1 (:unicode "😰"))
    #(":colombia:" 0 1 (:unicode "🇨🇴"))
    #(":comet:" 0 1 (:unicode "☄️"))
    #(":comoros:" 0 1 (:unicode "🇰🇲"))
    #(":compass:" 0 1 (:unicode "🧭"))
    #(":computer:" 0 1 (:unicode "💻"))
    #(":computer_mouse:" 0 1 (:unicode "🖱️"))
    #(":confetti_ball:" 0 1 (:unicode "🎊"))
    #(":confounded:" 0 1 (:unicode "😖"))
    #(":confused:" 0 1 (:unicode "😕"))
    #(":congo_brazzaville:" 0 1 (:unicode "🇨🇬"))
    #(":congo_kinshasa:" 0 1 (:unicode "🇨🇩"))
    #(":congratulations:" 0 1 (:unicode "㊗️"))
    #(":construction:" 0 1 (:unicode "🚧"))
    #(":construction_worker:" 0 1 (:unicode "👷"))
    #(":construction_worker_man:" 0 1 (:unicode "👷‍♂️"))
    #(":construction_worker_woman:" 0 1 (:unicode "👷‍♀️"))
    #(":control_knobs:" 0 1 (:unicode "🎛️"))
    #(":convenience_store:" 0 1 (:unicode "🏪"))
    #(":cook:" 0 1 (:unicode "🧑‍🍳"))
    #(":cook_islands:" 0 1 (:unicode "🇨🇰"))
    #(":cookie:" 0 1 (:unicode "🍪"))
    #(":cool:" 0 1 (:unicode "🆒"))
    #(":copyright:" 0 1 (:unicode "©️"))
    #(":coral:" 0 1 (:unicode "🪸"))
    #(":corn:" 0 1 (:unicode "🌽"))
    #(":costa_rica:" 0 1 (:unicode "🇨🇷"))
    #(":cote_divoire:" 0 1 (:unicode "🇨🇮"))
    #(":couch_and_lamp:" 0 1 (:unicode "🛋️"))
    #(":couple:" 0 1 (:unicode "👫"))
    #(":couple_with_heart:" 0 1 (:unicode "💑"))
    #(":couple_with_heart_man_man:" 0 1 (:unicode "👨‍❤️‍👨"))
    #(":couple_with_heart_woman_man:" 0 1 (:unicode "👩‍❤️‍👨"))
    #(":couple_with_heart_woman_woman:" 0 1 (:unicode "👩‍❤️‍👩"))
    #(":couplekiss:" 0 1 (:unicode "💏"))
    #(":couplekiss_man_man:" 0 1 (:unicode "👨‍❤️‍💋‍👨"))
    #(":couplekiss_man_woman:" 0 1 (:unicode "👩‍❤️‍💋‍👨"))
    #(":couplekiss_woman_woman:" 0 1 (:unicode "👩‍❤️‍💋‍👩"))
    #(":cow:" 0 1 (:unicode "🐮"))
    #(":cow2:" 0 1 (:unicode "🐄"))
    #(":cowboy_hat_face:" 0 1 (:unicode "🤠"))
    #(":crab:" 0 1 (:unicode "🦀"))
    #(":crayon:" 0 1 (:unicode "🖍️"))
    #(":credit_card:" 0 1 (:unicode "💳"))
    #(":crescent_moon:" 0 1 (:unicode "🌙"))
    #(":cricket:" 0 1 (:unicode "🦗"))
    #(":cricket_game:" 0 1 (:unicode "🏏"))
    #(":croatia:" 0 1 (:unicode "🇭🇷"))
    #(":crocodile:" 0 1 (:unicode "🐊"))
    #(":croissant:" 0 1 (:unicode "🥐"))
    #(":crossed_fingers:" 0 1 (:unicode "🤞"))
    #(":crossed_flags:" 0 1 (:unicode "🎌"))
    #(":crossed_swords:" 0 1 (:unicode "⚔️"))
    #(":crown:" 0 1 (:unicode "👑"))
    #(":crutch:" 0 1 (:unicode "🩼"))
    #(":cry:" 0 1 (:unicode "😢"))
    #(":crying_cat_face:" 0 1 (:unicode "😿"))
    #(":crystal_ball:" 0 1 (:unicode "🔮"))
    #(":cuba:" 0 1 (:unicode "🇨🇺"))
    #(":cucumber:" 0 1 (:unicode "🥒"))
    #(":cup_with_straw:" 0 1 (:unicode "🥤"))
    #(":cupcake:" 0 1 (:unicode "🧁"))
    #(":cupid:" 0 1 (:unicode "💘"))
    #(":curacao:" 0 1 (:unicode "🇨🇼"))
    #(":curling_stone:" 0 1 (:unicode "🥌"))
    #(":curly_haired_man:" 0 1 (:unicode "👨‍🦱"))
    #(":curly_haired_woman:" 0 1 (:unicode "👩‍🦱"))
    #(":curly_loop:" 0 1 (:unicode "➰"))
    #(":currency_exchange:" 0 1 (:unicode "💱"))
    #(":curry:" 0 1 (:unicode "🍛"))
    #(":cursing_face:" 0 1 (:unicode "🤬"))
    #(":custard:" 0 1 (:unicode "🍮"))
    #(":customs:" 0 1 (:unicode "🛃"))
    #(":cut_of_meat:" 0 1 (:unicode "🥩"))
    #(":cyclone:" 0 1 (:unicode "🌀"))
    #(":cyprus:" 0 1 (:unicode "🇨🇾"))
    #(":czech_republic:" 0 1 (:unicode "🇨🇿"))
    #(":dagger:" 0 1 (:unicode "🗡️"))
    #(":dancers:" 0 1 (:unicode "👯"))
    #(":dancing_men:" 0 1 (:unicode "👯‍♂️"))
    #(":dancing_women:" 0 1 (:unicode "👯‍♀️"))
    #(":dango:" 0 1 (:unicode "🍡"))
    #(":dark_sunglasses:" 0 1 (:unicode "🕶️"))
    #(":dart:" 0 1 (:unicode "🎯"))
    #(":dash:" 0 1 (:unicode "💨"))
    #(":date:" 0 1 (:unicode "📅"))
    #(":de:" 0 1 (:unicode "🇩🇪"))
    #(":deaf_man:" 0 1 (:unicode "🧏‍♂️"))
    #(":deaf_person:" 0 1 (:unicode "🧏"))
    #(":deaf_woman:" 0 1 (:unicode "🧏‍♀️"))
    #(":deciduous_tree:" 0 1 (:unicode "🌳"))
    #(":deer:" 0 1 (:unicode "🦌"))
    #(":denmark:" 0 1 (:unicode "🇩🇰"))
    #(":department_store:" 0 1 (:unicode "🏬"))
    #(":derelict_house:" 0 1 (:unicode "🏚️"))
    #(":desert:" 0 1 (:unicode "🏜️"))
    #(":desert_island:" 0 1 (:unicode "🏝️"))
    #(":desktop_computer:" 0 1 (:unicode "🖥️"))
    #(":detective:" 0 1 (:unicode "🕵️"))
    #(":diamond_shape_with_a_dot_inside:" 0 1 (:unicode "💠"))
    #(":diamonds:" 0 1 (:unicode "♦️"))
    #(":diego_garcia:" 0 1 (:unicode "🇩🇬"))
    #(":disappointed:" 0 1 (:unicode "😞"))
    #(":disappointed_relieved:" 0 1 (:unicode "😥"))
    #(":disguised_face:" 0 1 (:unicode "🥸"))
    #(":diving_mask:" 0 1 (:unicode "🤿"))
    #(":diya_lamp:" 0 1 (:unicode "🪔"))
    #(":dizzy:" 0 1 (:unicode "💫"))
    #(":dizzy_face:" 0 1 (:unicode "😵"))
    #(":djibouti:" 0 1 (:unicode "🇩🇯"))
    #(":dna:" 0 1 (:unicode "🧬"))
    #(":do_not_litter:" 0 1 (:unicode "🚯"))
    #(":dodo:" 0 1 (:unicode "🦤"))
    #(":dog:" 0 1 (:unicode "🐶"))
    #(":dog2:" 0 1 (:unicode "🐕"))
    #(":dollar:" 0 1 (:unicode "💵"))
    #(":dolls:" 0 1 (:unicode "🎎"))
    #(":dolphin:" 0 1 (:unicode "🐬"))
    #(":dominica:" 0 1 (:unicode "🇩🇲"))
    #(":dominican_republic:" 0 1 (:unicode "🇩🇴"))
    #(":donkey:" 0 1 (:unicode "🫏"))
    #(":door:" 0 1 (:unicode "🚪"))
    #(":dotted_line_face:" 0 1 (:unicode "🫥"))
    #(":doughnut:" 0 1 (:unicode "🍩"))
    #(":dove:" 0 1 (:unicode "🕊️"))
    #(":dragon:" 0 1 (:unicode "🐉"))
    #(":dragon_face:" 0 1 (:unicode "🐲"))
    #(":dress:" 0 1 (:unicode "👗"))
    #(":dromedary_camel:" 0 1 (:unicode "🐪"))
    #(":drooling_face:" 0 1 (:unicode "🤤"))
    #(":drop_of_blood:" 0 1 (:unicode "🩸"))
    #(":droplet:" 0 1 (:unicode "💧"))
    #(":drum:" 0 1 (:unicode "🥁"))
    #(":duck:" 0 1 (:unicode "🦆"))
    #(":dumpling:" 0 1 (:unicode "🥟"))
    #(":dvd:" 0 1 (:unicode "📀"))
    #(":eagle:" 0 1 (:unicode "🦅"))
    #(":ear:" 0 1 (:unicode "👂"))
    #(":ear_of_rice:" 0 1 (:unicode "🌾"))
    #(":ear_with_hearing_aid:" 0 1 (:unicode "🦻"))
    #(":earth_africa:" 0 1 (:unicode "🌍"))
    #(":earth_americas:" 0 1 (:unicode "🌎"))
    #(":earth_asia:" 0 1 (:unicode "🌏"))
    #(":ecuador:" 0 1 (:unicode "🇪🇨"))
    #(":egg:" 0 1 (:unicode "🥚"))
    #(":eggplant:" 0 1 (:unicode "🍆"))
    #(":egypt:" 0 1 (:unicode "🇪🇬"))
    #(":eight:" 0 1 (:unicode "8️⃣"))
    #(":eight_pointed_black_star:" 0 1 (:unicode "✴️"))
    #(":eight_spoked_asterisk:" 0 1 (:unicode "✳️"))
    #(":eject_button:" 0 1 (:unicode "⏏️"))
    #(":el_salvador:" 0 1 (:unicode "🇸🇻"))
    #(":electric_plug:" 0 1 (:unicode "🔌"))
    #(":elephant:" 0 1 (:unicode "🐘"))
    #(":elevator:" 0 1 (:unicode "🛗"))
    #(":elf:" 0 1 (:unicode "🧝"))
    #(":elf_man:" 0 1 (:unicode "🧝‍♂️"))
    #(":elf_woman:" 0 1 (:unicode "🧝‍♀️"))
    #(":email:" 0 1 (:unicode "📧"))
    #(":empty_nest:" 0 1 (:unicode "🪹"))
    #(":end:" 0 1 (:unicode "🔚"))
    #(":england:" 0 1 (:unicode "🏴󠁧󠁢󠁥󠁮󠁧󠁿"))
    #(":envelope:" 0 1 (:unicode "✉️"))
    #(":envelope_with_arrow:" 0 1 (:unicode "📩"))
    #(":equatorial_guinea:" 0 1 (:unicode "🇬🇶"))
    #(":eritrea:" 0 1 (:unicode "🇪🇷"))
    #(":es:" 0 1 (:unicode "🇪🇸"))
    #(":estonia:" 0 1 (:unicode "🇪🇪"))
    #(":ethiopia:" 0 1 (:unicode "🇪🇹"))
    #(":eu:" 0 1 (:unicode "🇪🇺"))
    #(":euro:" 0 1 (:unicode "💶"))
    #(":european_castle:" 0 1 (:unicode "🏰"))
    #(":european_post_office:" 0 1 (:unicode "🏤"))
    #(":evergreen_tree:" 0 1 (:unicode "🌲"))
    #(":exclamation:" 0 1 (:unicode "❗"))
    #(":exploding_head:" 0 1 (:unicode "🤯"))
    #(":expressionless:" 0 1 (:unicode "😑"))
    #(":eye:" 0 1 (:unicode "👁️"))
    #(":eye_speech_bubble:" 0 1 (:unicode "👁️‍🗨️"))
    #(":eyeglasses:" 0 1 (:unicode "👓"))
    #(":eyes:" 0 1 (:unicode "👀"))
    #(":face_exhaling:" 0 1 (:unicode "😮‍💨"))
    #(":face_holding_back_tears:" 0 1 (:unicode "🥹"))
    #(":face_in_clouds:" 0 1 (:unicode "😶‍🌫️"))
    #(":face_with_diagonal_mouth:" 0 1 (:unicode "🫤"))
    #(":face_with_head_bandage:" 0 1 (:unicode "🤕"))
    #(":face_with_open_eyes_and_hand_over_mouth:" 0 1 (:unicode "🫢"))
    #(":face_with_peeking_eye:" 0 1 (:unicode "🫣"))
    #(":face_with_spiral_eyes:" 0 1 (:unicode "😵‍💫"))
    #(":face_with_thermometer:" 0 1 (:unicode "🤒"))
    #(":facepalm:" 0 1 (:unicode "🤦"))
    #(":factory:" 0 1 (:unicode "🏭"))
    #(":factory_worker:" 0 1 (:unicode "🧑‍🏭"))
    #(":fairy:" 0 1 (:unicode "🧚"))
    #(":fairy_man:" 0 1 (:unicode "🧚‍♂️"))
    #(":fairy_woman:" 0 1 (:unicode "🧚‍♀️"))
    #(":falafel:" 0 1 (:unicode "🧆"))
    #(":falkland_islands:" 0 1 (:unicode "🇫🇰"))
    #(":fallen_leaf:" 0 1 (:unicode "🍂"))
    #(":family:" 0 1 (:unicode "👪"))
    #(":family_man_boy:" 0 1 (:unicode "👨‍👦"))
    #(":family_man_boy_boy:" 0 1 (:unicode "👨‍👦‍👦"))
    #(":family_man_girl:" 0 1 (:unicode "👨‍👧"))
    #(":family_man_girl_boy:" 0 1 (:unicode "👨‍👧‍👦"))
    #(":family_man_girl_girl:" 0 1 (:unicode "👨‍👧‍👧"))
    #(":family_man_man_boy:" 0 1 (:unicode "👨‍👨‍👦"))
    #(":family_man_man_boy_boy:" 0 1 (:unicode "👨‍👨‍👦‍👦"))
    #(":family_man_man_girl:" 0 1 (:unicode "👨‍👨‍👧"))
    #(":family_man_man_girl_boy:" 0 1 (:unicode "👨‍👨‍👧‍👦"))
    #(":family_man_man_girl_girl:" 0 1 (:unicode "👨‍👨‍👧‍👧"))
    #(":family_man_woman_boy:" 0 1 (:unicode "👨‍👩‍👦"))
    #(":family_man_woman_boy_boy:" 0 1 (:unicode "👨‍👩‍👦‍👦"))
    #(":family_man_woman_girl:" 0 1 (:unicode "👨‍👩‍👧"))
    #(":family_man_woman_girl_boy:" 0 1 (:unicode "👨‍👩‍👧‍👦"))
    #(":family_man_woman_girl_girl:" 0 1 (:unicode "👨‍👩‍👧‍👧"))
    #(":family_woman_boy:" 0 1 (:unicode "👩‍👦"))
    #(":family_woman_boy_boy:" 0 1 (:unicode "👩‍👦‍👦"))
    #(":family_woman_girl:" 0 1 (:unicode "👩‍👧"))
    #(":family_woman_girl_boy:" 0 1 (:unicode "👩‍👧‍👦"))
    #(":family_woman_girl_girl:" 0 1 (:unicode "👩‍👧‍👧"))
    #(":family_woman_woman_boy:" 0 1 (:unicode "👩‍👩‍👦"))
    #(":family_woman_woman_boy_boy:" 0 1 (:unicode "👩‍👩‍👦‍👦"))
    #(":family_woman_woman_girl:" 0 1 (:unicode "👩‍👩‍👧"))
    #(":family_woman_woman_girl_boy:" 0 1 (:unicode "👩‍👩‍👧‍👦"))
    #(":family_woman_woman_girl_girl:" 0 1 (:unicode "👩‍👩‍👧‍👧"))
    #(":farmer:" 0 1 (:unicode "🧑‍🌾"))
    #(":faroe_islands:" 0 1 (:unicode "🇫🇴"))
    #(":fast_forward:" 0 1 (:unicode "⏩"))
    #(":fax:" 0 1 (:unicode "📠"))
    #(":fearful:" 0 1 (:unicode "😨"))
    #(":feather:" 0 1 (:unicode "🪶"))
    #(":feet:" 0 1 (:unicode "🐾"))
    #(":female:" 0 1 (:unicode "♀"))
    #(":female_detective:" 0 1 (:unicode "🕵️‍♀️"))
    #(":female_sign:" 0 1 (:unicode "♀️"))
    #(":ferris_wheel:" 0 1 (:unicode "🎡"))
    #(":ferry:" 0 1 (:unicode "⛴️"))
    #(":field_hockey:" 0 1 (:unicode "🏑"))
    #(":fiji:" 0 1 (:unicode "🇫🇯"))
    #(":file_cabinet:" 0 1 (:unicode "🗄️"))
    #(":file_folder:" 0 1 (:unicode "📁"))
    #(":film_projector:" 0 1 (:unicode "📽️"))
    #(":film_strip:" 0 1 (:unicode "🎞️"))
    #(":finland:" 0 1 (:unicode "🇫🇮"))
    #(":fire:" 0 1 (:unicode "🔥"))
    #(":fire_engine:" 0 1 (:unicode "🚒"))
    #(":fire_extinguisher:" 0 1 (:unicode "🧯"))
    #(":firecracker:" 0 1 (:unicode "🧨"))
    #(":firefighter:" 0 1 (:unicode "🧑‍🚒"))
    #(":fireworks:" 0 1 (:unicode "🎆"))
    #(":first_quarter_moon:" 0 1 (:unicode "🌓"))
    #(":first_quarter_moon_with_face:" 0 1 (:unicode "🌛"))
    #(":fish:" 0 1 (:unicode "🐟"))
    #(":fish_cake:" 0 1 (:unicode "🍥"))
    #(":fishing_pole_and_fish:" 0 1 (:unicode "🎣"))
    #(":fist_left:" 0 1 (:unicode "🤛"))
    #(":fist_oncoming:" 0 1 (:unicode "👊"))
    #(":fist_raised:" 0 1 (:unicode "✊"))
    #(":fist_right:" 0 1 (:unicode "🤜"))
    #(":five:" 0 1 (:unicode "5️⃣"))
    #(":flags:" 0 1 (:unicode "🎏"))
    #(":flamingo:" 0 1 (:unicode "🦩"))
    #(":flashlight:" 0 1 (:unicode "🔦"))
    #(":flat_shoe:" 0 1 (:unicode "🥿"))
    #(":flatbread:" 0 1 (:unicode "🫓"))
    #(":fleur_de_lis:" 0 1 (:unicode "⚜️"))
    #(":flight_arrival:" 0 1 (:unicode "🛬"))
    #(":flight_departure:" 0 1 (:unicode "🛫"))
    #(":floppy_disk:" 0 1 (:unicode "💾"))
    #(":flower_playing_cards:" 0 1 (:unicode "🎴"))
    #(":flushed:" 0 1 (:unicode "😳"))
    #(":flute:" 0 1 (:unicode "🪈"))
    #(":fly:" 0 1 (:unicode "🪰"))
    #(":flying_disc:" 0 1 (:unicode "🥏"))
    #(":flying_saucer:" 0 1 (:unicode "🛸"))
    #(":fog:" 0 1 (:unicode "🌫️"))
    #(":foggy:" 0 1 (:unicode "🌁"))
    #(":folding_hand_fan:" 0 1 (:unicode "🪭"))
    #(":fondue:" 0 1 (:unicode "🫕"))
    #(":foot:" 0 1 (:unicode "🦶"))
    #(":football:" 0 1 (:unicode "🏈"))
    #(":footprints:" 0 1 (:unicode "👣"))
    #(":fork_and_knife:" 0 1 (:unicode "🍴"))
    #(":fortune_cookie:" 0 1 (:unicode "🥠"))
    #(":fountain:" 0 1 (:unicode "⛲"))
    #(":fountain_pen:" 0 1 (:unicode "🖋️"))
    #(":four:" 0 1 (:unicode "4️⃣"))
    #(":four_leaf_clover:" 0 1 (:unicode "🍀"))
    #(":fox_face:" 0 1 (:unicode "🦊"))
    #(":fr:" 0 1 (:unicode "🇫🇷"))
    #(":framed_picture:" 0 1 (:unicode "🖼️"))
    #(":free:" 0 1 (:unicode "🆓"))
    #(":french_guiana:" 0 1 (:unicode "🇬🇫"))
    #(":french_polynesia:" 0 1 (:unicode "🇵🇫"))
    #(":french_southern_territories:" 0 1 (:unicode "🇹🇫"))
    #(":fried_egg:" 0 1 (:unicode "🍳"))
    #(":fried_shrimp:" 0 1 (:unicode "🍤"))
    #(":fries:" 0 1 (:unicode "🍟"))
    #(":frog:" 0 1 (:unicode "🐸"))
    #(":frowning:" 0 1 (:unicode "😦"))
    #(":frowning_face:" 0 1 (:unicode "☹️"))
    #(":frowning_man:" 0 1 (:unicode "🙍‍♂️"))
    #(":frowning_person:" 0 1 (:unicode "🙍"))
    #(":frowning_woman:" 0 1 (:unicode "🙍‍♀️"))
    #(":fuelpump:" 0 1 (:unicode "⛽"))
    #(":full_moon:" 0 1 (:unicode "🌕"))
    #(":full_moon_with_face:" 0 1 (:unicode "🌝"))
    #(":funeral_urn:" 0 1 (:unicode "⚱️"))
    #(":gabon:" 0 1 (:unicode "🇬🇦"))
    #(":gambia:" 0 1 (:unicode "🇬🇲"))
    #(":game_die:" 0 1 (:unicode "🎲"))
    #(":garlic:" 0 1 (:unicode "🧄"))
    #(":gb:" 0 1 (:unicode "🇬🇧"))
    #(":gear:" 0 1 (:unicode "⚙️"))
    #(":gem:" 0 1 (:unicode "💎"))
    #(":gemini:" 0 1 (:unicode "♊"))
    #(":genie:" 0 1 (:unicode "🧞"))
    #(":genie_man:" 0 1 (:unicode "🧞‍♂️"))
    #(":genie_woman:" 0 1 (:unicode "🧞‍♀️"))
    #(":georgia:" 0 1 (:unicode "🇬🇪"))
    #(":ghana:" 0 1 (:unicode "🇬🇭"))
    #(":ghost:" 0 1 (:unicode "👻"))
    #(":gibraltar:" 0 1 (:unicode "🇬🇮"))
    #(":gift:" 0 1 (:unicode "🎁"))
    #(":gift_heart:" 0 1 (:unicode "💝"))
    #(":ginger_root:" 0 1 (:unicode "🫚"))
    #(":giraffe:" 0 1 (:unicode "🦒"))
    #(":girl:" 0 1 (:unicode "👧"))
    #(":globe_with_meridians:" 0 1 (:unicode "🌐"))
    #(":gloves:" 0 1 (:unicode "🧤"))
    #(":goal_net:" 0 1 (:unicode "🥅"))
    #(":goat:" 0 1 (:unicode "🐐"))
    #(":goggles:" 0 1 (:unicode "🥽"))
    #(":golf:" 0 1 (:unicode "⛳"))
    #(":golfing:" 0 1 (:unicode "🏌️"))
    #(":golfing_man:" 0 1 (:unicode "🏌️‍♂️"))
    #(":golfing_woman:" 0 1 (:unicode "🏌️‍♀️"))
    #(":goose:" 0 1 (:unicode "🪿"))
    #(":gorilla:" 0 1 (:unicode "🦍"))
    #(":grapes:" 0 1 (:unicode "🍇"))
    #(":greece:" 0 1 (:unicode "🇬🇷"))
    #(":green_apple:" 0 1 (:unicode "🍏"))
    #(":green_book:" 0 1 (:unicode "📗"))
    #(":green_circle:" 0 1 (:unicode "🟢"))
    #(":green_heart:" 0 1 (:unicode "💚"))
    #(":green_salad:" 0 1 (:unicode "🥗"))
    #(":green_square:" 0 1 (:unicode "🟩"))
    #(":greenland:" 0 1 (:unicode "🇬🇱"))
    #(":grenada:" 0 1 (:unicode "🇬🇩"))
    #(":grey_exclamation:" 0 1 (:unicode "❕"))
    #(":grey_heart:" 0 1 (:unicode "🩶"))
    #(":grey_question:" 0 1 (:unicode "❔"))
    #(":grimacing:" 0 1 (:unicode "😬"))
    #(":grin:" 0 1 (:unicode "😁"))
    #(":grinning:" 0 1 (:unicode "😀"))
    #(":guadeloupe:" 0 1 (:unicode "🇬🇵"))
    #(":guam:" 0 1 (:unicode "🇬🇺"))
    #(":guard:" 0 1 (:unicode "💂"))
    #(":guardsman:" 0 1 (:unicode "💂‍♂️"))
    #(":guardswoman:" 0 1 (:unicode "💂‍♀️"))
    #(":guatemala:" 0 1 (:unicode "🇬🇹"))
    #(":guernsey:" 0 1 (:unicode "🇬🇬"))
    #(":guide_dog:" 0 1 (:unicode "🦮"))
    #(":guinea:" 0 1 (:unicode "🇬🇳"))
    #(":guinea_bissau:" 0 1 (:unicode "🇬🇼"))
    #(":guitar:" 0 1 (:unicode "🎸"))
    #(":gun:" 0 1 (:unicode "🔫"))
    #(":guyana:" 0 1 (:unicode "🇬🇾"))
    #(":hair_pick:" 0 1 (:unicode "🪮"))
    #(":haircut:" 0 1 (:unicode "💇"))
    #(":haircut_man:" 0 1 (:unicode "💇‍♂️"))
    #(":haircut_woman:" 0 1 (:unicode "💇‍♀️"))
    #(":haiti:" 0 1 (:unicode "🇭🇹"))
    #(":hamburger:" 0 1 (:unicode "🍔"))
    #(":hammer:" 0 1 (:unicode "🔨"))
    #(":hammer_and_pick:" 0 1 (:unicode "⚒️"))
    #(":hammer_and_wrench:" 0 1 (:unicode "🛠️"))
    #(":hamsa:" 0 1 (:unicode "🪬"))
    #(":hamster:" 0 1 (:unicode "🐹"))
    #(":hand:" 0 1 (:unicode "✋"))
    #(":hand_over_mouth:" 0 1 (:unicode "🤭"))
    #(":hand_with_index_finger_and_thumb_crossed:" 0 1 (:unicode "🫰"))
    #(":handbag:" 0 1 (:unicode "👜"))
    #(":handball_person:" 0 1 (:unicode "🤾"))
    #(":handshake:" 0 1 (:unicode "🤝"))
    #(":hankey:" 0 1 (:unicode "💩"))
    #(":hash:" 0 1 (:unicode "#️⃣"))
    #(":hatched_chick:" 0 1 (:unicode "🐥"))
    #(":hatching_chick:" 0 1 (:unicode "🐣"))
    #(":headphones:" 0 1 (:unicode "🎧"))
    #(":headstone:" 0 1 (:unicode "🪦"))
    #(":health_worker:" 0 1 (:unicode "🧑‍⚕️"))
    #(":hear_no_evil:" 0 1 (:unicode "🙉"))
    #(":heard_mcdonald_islands:" 0 1 (:unicode "🇭🇲"))
    #(":heart:" 0 1 (:unicode "❤️"))
    #(":heart_decoration:" 0 1 (:unicode "💟"))
    #(":heart_eyes:" 0 1 (:unicode "😍"))
    #(":heart_eyes_cat:" 0 1 (:unicode "😻"))
    #(":heart_hands:" 0 1 (:unicode "🫶"))
    #(":heart_on_fire:" 0 1 (:unicode "❤️‍🔥"))
    #(":heartbeat:" 0 1 (:unicode "💓"))
    #(":heartpulse:" 0 1 (:unicode "💗"))
    #(":hearts:" 0 1 (:unicode "♥️"))
    #(":heavy_check_mark:" 0 1 (:unicode "✔️"))
    #(":heavy_division_sign:" 0 1 (:unicode "➗"))
    #(":heavy_dollar_sign:" 0 1 (:unicode "💲"))
    #(":heavy_equals_sign:" 0 1 (:unicode "🟰"))
    #(":heavy_heart_exclamation:" 0 1 (:unicode "❣️"))
    #(":heavy_minus_sign:" 0 1 (:unicode "➖"))
    #(":heavy_multiplication_x:" 0 1 (:unicode "✖️"))
    #(":heavy_plus_sign:" 0 1 (:unicode "➕"))
    #(":hedgehog:" 0 1 (:unicode "🦔"))
    #(":helicopter:" 0 1 (:unicode "🚁"))
    #(":herb:" 0 1 (:unicode "🌿"))
    #(":hibiscus:" 0 1 (:unicode "🌺"))
    #(":high_brightness:" 0 1 (:unicode "🔆"))
    #(":high_heel:" 0 1 (:unicode "👠"))
    #(":hiking_boot:" 0 1 (:unicode "🥾"))
    #(":hindu_temple:" 0 1 (:unicode "🛕"))
    #(":hippopotamus:" 0 1 (:unicode "🦛"))
    #(":hocho:" 0 1 (:unicode "🔪"))
    #(":hole:" 0 1 (:unicode "🕳️"))
    #(":honduras:" 0 1 (:unicode "🇭🇳"))
    #(":honey_pot:" 0 1 (:unicode "🍯"))
    #(":hong_kong:" 0 1 (:unicode "🇭🇰"))
    #(":hook:" 0 1 (:unicode "🪝"))
    #(":horse:" 0 1 (:unicode "🐴"))
    #(":horse_racing:" 0 1 (:unicode "🏇"))
    #(":hospital:" 0 1 (:unicode "🏥"))
    #(":hot_face:" 0 1 (:unicode "🥵"))
    #(":hot_pepper:" 0 1 (:unicode "🌶️"))
    #(":hotdog:" 0 1 (:unicode "🌭"))
    #(":hotel:" 0 1 (:unicode "🏨"))
    #(":hotsprings:" 0 1 (:unicode "♨️"))
    #(":hourglass:" 0 1 (:unicode "⌛"))
    #(":hourglass_flowing_sand:" 0 1 (:unicode "⏳"))
    #(":house:" 0 1 (:unicode "🏠"))
    #(":house_with_garden:" 0 1 (:unicode "🏡"))
    #(":houses:" 0 1 (:unicode "🏘️"))
    #(":hugs:" 0 1 (:unicode "🤗"))
    #(":hungary:" 0 1 (:unicode "🇭🇺"))
    #(":hushed:" 0 1 (:unicode "😯"))
    #(":hut:" 0 1 (:unicode "🛖"))
    #(":hyacinth:" 0 1 (:unicode "🪻"))
    #(":ice_cream:" 0 1 (:unicode "🍨"))
    #(":ice_cube:" 0 1 (:unicode "🧊"))
    #(":ice_hockey:" 0 1 (:unicode "🏒"))
    #(":ice_skate:" 0 1 (:unicode "⛸️"))
    #(":icecream:" 0 1 (:unicode "🍦"))
    #(":iceland:" 0 1 (:unicode "🇮🇸"))
    #(":id:" 0 1 (:unicode "🆔"))
    #(":identification_card:" 0 1 (:unicode "🪪"))
    #(":ideograph_advantage:" 0 1 (:unicode "🉐"))
    #(":imp:" 0 1 (:unicode "👿"))
    #(":inbox_tray:" 0 1 (:unicode "📥"))
    #(":incoming_envelope:" 0 1 (:unicode "📨"))
    #(":index_pointing_at_the_viewer:" 0 1 (:unicode "🫵"))
    #(":india:" 0 1 (:unicode "🇮🇳"))
    #(":indonesia:" 0 1 (:unicode "🇮🇩"))
    #(":infinity:" 0 1 (:unicode "♾️"))
    #(":information_source:" 0 1 (:unicode "ℹ️"))
    #(":innocent:" 0 1 (:unicode "😇"))
    #(":interrobang:" 0 1 (:unicode "⁉️"))
    #(":iphone:" 0 1 (:unicode "📱"))
    #(":iran:" 0 1 (:unicode "🇮🇷"))
    #(":iraq:" 0 1 (:unicode "🇮🇶"))
    #(":ireland:" 0 1 (:unicode "🇮🇪"))
    #(":isle_of_man:" 0 1 (:unicode "🇮🇲"))
    #(":israel:" 0 1 (:unicode "🇮🇱"))
    #(":it:" 0 1 (:unicode "🇮🇹"))
    #(":izakaya_lantern:" 0 1 (:unicode "🏮"))
    #(":jack_o_lantern:" 0 1 (:unicode "🎃"))
    #(":jamaica:" 0 1 (:unicode "🇯🇲"))
    #(":japan:" 0 1 (:unicode "🗾"))
    #(":japanese_castle:" 0 1 (:unicode "🏯"))
    #(":japanese_goblin:" 0 1 (:unicode "👺"))
    #(":japanese_ogre:" 0 1 (:unicode "👹"))
    #(":jar:" 0 1 (:unicode "🫙"))
    #(":jeans:" 0 1 (:unicode "👖"))
    #(":jellyfish:" 0 1 (:unicode "🪼"))
    #(":jersey:" 0 1 (:unicode "🇯🇪"))
    #(":jigsaw:" 0 1 (:unicode "🧩"))
    #(":jordan:" 0 1 (:unicode "🇯🇴"))
    #(":joy:" 0 1 (:unicode "😂"))
    #(":joy_cat:" 0 1 (:unicode "😹"))
    #(":joystick:" 0 1 (:unicode "🕹️"))
    #(":jp:" 0 1 (:unicode "🇯🇵"))
    #(":judge:" 0 1 (:unicode "🧑‍⚖️"))
    #(":juggling_person:" 0 1 (:unicode "🤹"))
    #(":kaaba:" 0 1 (:unicode "🕋"))
    #(":kangaroo:" 0 1 (:unicode "🦘"))
    #(":kazakhstan:" 0 1 (:unicode "🇰🇿"))
    #(":kenya:" 0 1 (:unicode "🇰🇪"))
    #(":key:" 0 1 (:unicode "🔑"))
    #(":keyboard:" 0 1 (:unicode "⌨️"))
    #(":keycap_ten:" 0 1 (:unicode "🔟"))
    #(":khanda:" 0 1 (:unicode "🪯"))
    #(":kick_scooter:" 0 1 (:unicode "🛴"))
    #(":kimono:" 0 1 (:unicode "👘"))
    #(":kiribati:" 0 1 (:unicode "🇰🇮"))
    #(":kiss:" 0 1 (:unicode "💋"))
    #(":kissing:" 0 1 (:unicode "😗"))
    #(":kissing_cat:" 0 1 (:unicode "😽"))
    #(":kissing_closed_eyes:" 0 1 (:unicode "😚"))
    #(":kissing_heart:" 0 1 (:unicode "😘"))
    #(":kissing_smiling_eyes:" 0 1 (:unicode "😙"))
    #(":kite:" 0 1 (:unicode "🪁"))
    #(":kiwi_fruit:" 0 1 (:unicode "🥝"))
    #(":kneeling_man:" 0 1 (:unicode "🧎‍♂️"))
    #(":kneeling_person:" 0 1 (:unicode "🧎"))
    #(":kneeling_woman:" 0 1 (:unicode "🧎‍♀️"))
    #(":knot:" 0 1 (:unicode "🪢"))
    #(":koala:" 0 1 (:unicode "🐨"))
    #(":koko:" 0 1 (:unicode "🈁"))
    #(":kosovo:" 0 1 (:unicode "🇽🇰"))
    #(":kr:" 0 1 (:unicode "🇰🇷"))
    #(":kuwait:" 0 1 (:unicode "🇰🇼"))
    #(":kyrgyzstan:" 0 1 (:unicode "🇰🇬"))
    #(":lab_coat:" 0 1 (:unicode "🥼"))
    #(":label:" 0 1 (:unicode "🏷️"))
    #(":lacrosse:" 0 1 (:unicode "🥍"))
    #(":ladder:" 0 1 (:unicode "🪜"))
    #(":lady_beetle:" 0 1 (:unicode "🐞"))
    #(":laos:" 0 1 (:unicode "🇱🇦"))
    #(":large_blue_circle:" 0 1 (:unicode "🔵"))
    #(":large_blue_diamond:" 0 1 (:unicode "🔷"))
    #(":large_orange_diamond:" 0 1 (:unicode "🔶"))
    #(":last_quarter_moon:" 0 1 (:unicode "🌗"))
    #(":last_quarter_moon_with_face:" 0 1 (:unicode "🌜"))
    #(":latin_cross:" 0 1 (:unicode "✝️"))
    #(":latvia:" 0 1 (:unicode "🇱🇻"))
    #(":laughing:" 0 1 (:unicode "😆"))
    #(":leafy_green:" 0 1 (:unicode "🥬"))
    #(":leaves:" 0 1 (:unicode "🍃"))
    #(":lebanon:" 0 1 (:unicode "🇱🇧"))
    #(":ledger:" 0 1 (:unicode "📒"))
    #(":left_luggage:" 0 1 (:unicode "🛅"))
    #(":left_right_arrow:" 0 1 (:unicode "↔️"))
    #(":left_speech_bubble:" 0 1 (:unicode "🗨️"))
    #(":leftwards_arrow_with_hook:" 0 1 (:unicode "↩️"))
    #(":leftwards_hand:" 0 1 (:unicode "🫲"))
    #(":leftwards_pushing_hand:" 0 1 (:unicode "🫷"))
    #(":leg:" 0 1 (:unicode "🦵"))
    #(":lemon:" 0 1 (:unicode "🍋"))
    #(":leo:" 0 1 (:unicode "♌"))
    #(":leopard:" 0 1 (:unicode "🐆"))
    #(":lesotho:" 0 1 (:unicode "🇱🇸"))
    #(":level_slider:" 0 1 (:unicode "🎚️"))
    #(":liberia:" 0 1 (:unicode "🇱🇷"))
    #(":libra:" 0 1 (:unicode "♎"))
    #(":libya:" 0 1 (:unicode "🇱🇾"))
    #(":liechtenstein:" 0 1 (:unicode "🇱🇮"))
    #(":light_blue_heart:" 0 1 (:unicode "🩵"))
    #(":light_rail:" 0 1 (:unicode "🚈"))
    #(":link:" 0 1 (:unicode "🔗"))
    #(":lion:" 0 1 (:unicode "🦁"))
    #(":lips:" 0 1 (:unicode "👄"))
    #(":lipstick:" 0 1 (:unicode "💄"))
    #(":lithuania:" 0 1 (:unicode "🇱🇹"))
    #(":lizard:" 0 1 (:unicode "🦎"))
    #(":llama:" 0 1 (:unicode "🦙"))
    #(":lobster:" 0 1 (:unicode "🦞"))
    #(":lock:" 0 1 (:unicode "🔒"))
    #(":lock_with_ink_pen:" 0 1 (:unicode "🔏"))
    #(":lollipop:" 0 1 (:unicode "🍭"))
    #(":long_drum:" 0 1 (:unicode "🪘"))
    #(":loop:" 0 1 (:unicode "➿"))
    #(":lotion_bottle:" 0 1 (:unicode "🧴"))
    #(":lotus:" 0 1 (:unicode "🪷"))
    #(":lotus_position:" 0 1 (:unicode "🧘"))
    #(":lotus_position_man:" 0 1 (:unicode "🧘‍♂️"))
    #(":lotus_position_woman:" 0 1 (:unicode "🧘‍♀️"))
    #(":loud_sound:" 0 1 (:unicode "🔊"))
    #(":loudspeaker:" 0 1 (:unicode "📢"))
    #(":love_hotel:" 0 1 (:unicode "🏩"))
    #(":love_letter:" 0 1 (:unicode "💌"))
    #(":love_you_gesture:" 0 1 (:unicode "🤟"))
    #(":low_battery:" 0 1 (:unicode "🪫"))
    #(":low_brightness:" 0 1 (:unicode "🔅"))
    #(":luggage:" 0 1 (:unicode "🧳"))
    #(":lungs:" 0 1 (:unicode "🫁"))
    #(":luxembourg:" 0 1 (:unicode "🇱🇺"))
    #(":lying_face:" 0 1 (:unicode "🤥"))
    #(":m:" 0 1 (:unicode "Ⓜ️"))
    #(":macau:" 0 1 (:unicode "🇲🇴"))
    #(":macedonia:" 0 1 (:unicode "🇲🇰"))
    #(":madagascar:" 0 1 (:unicode "🇲🇬"))
    #(":mag:" 0 1 (:unicode "🔍"))
    #(":mag_right:" 0 1 (:unicode "🔎"))
    #(":mage:" 0 1 (:unicode "🧙"))
    #(":mage_man:" 0 1 (:unicode "🧙‍♂️"))
    #(":mage_woman:" 0 1 (:unicode "🧙‍♀️"))
    #(":magic_wand:" 0 1 (:unicode "🪄"))
    #(":magnet:" 0 1 (:unicode "🧲"))
    #(":mahjong:" 0 1 (:unicode "🀄"))
    #(":mailbox:" 0 1 (:unicode "📫"))
    #(":mailbox_closed:" 0 1 (:unicode "📪"))
    #(":mailbox_with_mail:" 0 1 (:unicode "📬"))
    #(":mailbox_with_no_mail:" 0 1 (:unicode "📭"))
    #(":malawi:" 0 1 (:unicode "🇲🇼"))
    #(":malaysia:" 0 1 (:unicode "🇲🇾"))
    #(":maldives:" 0 1 (:unicode "🇲🇻"))
    #(":male:" 0 1 (:unicode "♂"))
    #(":male_detective:" 0 1 (:unicode "🕵️‍♂️"))
    #(":male_sign:" 0 1 (:unicode "♂️"))
    #(":mali:" 0 1 (:unicode "🇲🇱"))
    #(":malta:" 0 1 (:unicode "🇲🇹"))
    #(":mammoth:" 0 1 (:unicode "🦣"))
    #(":man:" 0 1 (:unicode "👨"))
    #(":man_artist:" 0 1 (:unicode "👨‍🎨"))
    #(":man_astronaut:" 0 1 (:unicode "👨‍🚀"))
    #(":man_beard:" 0 1 (:unicode "🧔‍♂️"))
    #(":man_cartwheeling:" 0 1 (:unicode "🤸‍♂️"))
    #(":man_cook:" 0 1 (:unicode "👨‍🍳"))
    #(":man_dancing:" 0 1 (:unicode "🕺"))
    #(":man_facepalming:" 0 1 (:unicode "🤦‍♂️"))
    #(":man_factory_worker:" 0 1 (:unicode "👨‍🏭"))
    #(":man_farmer:" 0 1 (:unicode "👨‍🌾"))
    #(":man_feeding_baby:" 0 1 (:unicode "👨‍🍼"))
    #(":man_firefighter:" 0 1 (:unicode "👨‍🚒"))
    #(":man_health_worker:" 0 1 (:unicode "👨‍⚕️"))
    #(":man_in_manual_wheelchair:" 0 1 (:unicode "👨‍🦽"))
    #(":man_in_motorized_wheelchair:" 0 1 (:unicode "👨‍🦼"))
    #(":man_in_tuxedo:" 0 1 (:unicode "🤵‍♂️"))
    #(":man_judge:" 0 1 (:unicode "👨‍⚖️"))
    #(":man_juggling:" 0 1 (:unicode "🤹‍♂️"))
    #(":man_mechanic:" 0 1 (:unicode "👨‍🔧"))
    #(":man_office_worker:" 0 1 (:unicode "👨‍💼"))
    #(":man_pilot:" 0 1 (:unicode "👨‍✈️"))
    #(":man_playing_handball:" 0 1 (:unicode "🤾‍♂️"))
    #(":man_playing_water_polo:" 0 1 (:unicode "🤽‍♂️"))
    #(":man_scientist:" 0 1 (:unicode "👨‍🔬"))
    #(":man_shrugging:" 0 1 (:unicode "🤷‍♂️"))
    #(":man_singer:" 0 1 (:unicode "👨‍🎤"))
    #(":man_student:" 0 1 (:unicode "👨‍🎓"))
    #(":man_teacher:" 0 1 (:unicode "👨‍🏫"))
    #(":man_technologist:" 0 1 (:unicode "👨‍💻"))
    #(":man_with_gua_pi_mao:" 0 1 (:unicode "👲"))
    #(":man_with_probing_cane:" 0 1 (:unicode "👨‍🦯"))
    #(":man_with_turban:" 0 1 (:unicode "👳‍♂️"))
    #(":man_with_veil:" 0 1 (:unicode "👰‍♂️"))
    #(":mango:" 0 1 (:unicode "🥭"))
    #(":mans_shoe:" 0 1 (:unicode "👞"))
    #(":mantelpiece_clock:" 0 1 (:unicode "🕰️"))
    #(":manual_wheelchair:" 0 1 (:unicode "🦽"))
    #(":maple_leaf:" 0 1 (:unicode "🍁"))
    #(":maracas:" 0 1 (:unicode "🪇"))
    #(":marshall_islands:" 0 1 (:unicode "🇲🇭"))
    #(":martial_arts_uniform:" 0 1 (:unicode "🥋"))
    #(":martinique:" 0 1 (:unicode "🇲🇶"))
    #(":mask:" 0 1 (:unicode "😷"))
    #(":massage:" 0 1 (:unicode "💆"))
    #(":massage_man:" 0 1 (:unicode "💆‍♂️"))
    #(":massage_woman:" 0 1 (:unicode "💆‍♀️"))
    #(":mate:" 0 1 (:unicode "🧉"))
    #(":mauritania:" 0 1 (:unicode "🇲🇷"))
    #(":mauritius:" 0 1 (:unicode "🇲🇺"))
    #(":mayotte:" 0 1 (:unicode "🇾🇹"))
    #(":meat_on_bone:" 0 1 (:unicode "🍖"))
    #(":mechanic:" 0 1 (:unicode "🧑‍🔧"))
    #(":mechanical_arm:" 0 1 (:unicode "🦾"))
    #(":mechanical_leg:" 0 1 (:unicode "🦿"))
    #(":medal_military:" 0 1 (:unicode "🎖️"))
    #(":medal_sports:" 0 1 (:unicode "🏅"))
    #(":medical_symbol:" 0 1 (:unicode "⚕️"))
    #(":mega:" 0 1 (:unicode "📣"))
    #(":melon:" 0 1 (:unicode "🍈"))
    #(":melting_face:" 0 1 (:unicode "🫠"))
    #(":memo:" 0 1 (:unicode "📝"))
    #(":men_wrestling:" 0 1 (:unicode "🤼‍♂️"))
    #(":mending_heart:" 0 1 (:unicode "❤️‍🩹"))
    #(":menorah:" 0 1 (:unicode "🕎"))
    #(":mens:" 0 1 (:unicode "🚹"))
    #(":mermaid:" 0 1 (:unicode "🧜‍♀️"))
    #(":merman:" 0 1 (:unicode "🧜‍♂️"))
    #(":merperson:" 0 1 (:unicode "🧜"))
    #(":metal:" 0 1 (:unicode "🤘"))
    #(":metro:" 0 1 (:unicode "🚇"))
    #(":mexico:" 0 1 (:unicode "🇲🇽"))
    #(":microbe:" 0 1 (:unicode "🦠"))
    #(":micronesia:" 0 1 (:unicode "🇫🇲"))
    #(":microphone:" 0 1 (:unicode "🎤"))
    #(":microscope:" 0 1 (:unicode "🔬"))
    #(":middle_finger:" 0 1 (:unicode "🖕"))
    #(":military_helmet:" 0 1 (:unicode "🪖"))
    #(":milk_glass:" 0 1 (:unicode "🥛"))
    #(":milky_way:" 0 1 (:unicode "🌌"))
    #(":minibus:" 0 1 (:unicode "🚐"))
    #(":minidisc:" 0 1 (:unicode "💽"))
    #(":mirror:" 0 1 (:unicode "🪞"))
    #(":mirror_ball:" 0 1 (:unicode "🪩"))
    #(":mobile_phone_off:" 0 1 (:unicode "📴"))
    #(":moldova:" 0 1 (:unicode "🇲🇩"))
    #(":monaco:" 0 1 (:unicode "🇲🇨"))
    #(":money_mouth_face:" 0 1 (:unicode "🤑"))
    #(":money_with_wings:" 0 1 (:unicode "💸"))
    #(":moneybag:" 0 1 (:unicode "💰"))
    #(":mongolia:" 0 1 (:unicode "🇲🇳"))
    #(":monkey:" 0 1 (:unicode "🐒"))
    #(":monkey_face:" 0 1 (:unicode "🐵"))
    #(":monocle_face:" 0 1 (:unicode "🧐"))
    #(":monorail:" 0 1 (:unicode "🚝"))
    #(":montenegro:" 0 1 (:unicode "🇲🇪"))
    #(":montserrat:" 0 1 (:unicode "🇲🇸"))
    #(":moon:" 0 1 (:unicode "🌔"))
    #(":moon_cake:" 0 1 (:unicode "🥮"))
    #(":moose:" 0 1 (:unicode "🫎"))
    #(":morocco:" 0 1 (:unicode "🇲🇦"))
    #(":mortar_board:" 0 1 (:unicode "🎓"))
    #(":mosque:" 0 1 (:unicode "🕌"))
    #(":mosquito:" 0 1 (:unicode "🦟"))
    #(":motor_boat:" 0 1 (:unicode "🛥️"))
    #(":motor_scooter:" 0 1 (:unicode "🛵"))
    #(":motorcycle:" 0 1 (:unicode "🏍️"))
    #(":motorized_wheelchair:" 0 1 (:unicode "🦼"))
    #(":motorway:" 0 1 (:unicode "🛣️"))
    #(":mount_fuji:" 0 1 (:unicode "🗻"))
    #(":mountain:" 0 1 (:unicode "⛰️"))
    #(":mountain_bicyclist:" 0 1 (:unicode "🚵"))
    #(":mountain_biking_man:" 0 1 (:unicode "🚵‍♂️"))
    #(":mountain_biking_woman:" 0 1 (:unicode "🚵‍♀️"))
    #(":mountain_cableway:" 0 1 (:unicode "🚠"))
    #(":mountain_railway:" 0 1 (:unicode "🚞"))
    #(":mountain_snow:" 0 1 (:unicode "🏔️"))
    #(":mouse:" 0 1 (:unicode "🐭"))
    #(":mouse2:" 0 1 (:unicode "🐁"))
    #(":mouse_trap:" 0 1 (:unicode "🪤"))
    #(":movie_camera:" 0 1 (:unicode "🎥"))
    #(":moyai:" 0 1 (:unicode "🗿"))
    #(":mozambique:" 0 1 (:unicode "🇲🇿"))
    #(":mrs_claus:" 0 1 (:unicode "🤶"))
    #(":muscle:" 0 1 (:unicode "💪"))
    #(":mushroom:" 0 1 (:unicode "🍄"))
    #(":musical_keyboard:" 0 1 (:unicode "🎹"))
    #(":musical_note:" 0 1 (:unicode "🎵"))
    #(":musical_score:" 0 1 (:unicode "🎼"))
    #(":mute:" 0 1 (:unicode "🔇"))
    #(":mx_claus:" 0 1 (:unicode "🧑‍🎄"))
    #(":myanmar:" 0 1 (:unicode "🇲🇲"))
    #(":nail_care:" 0 1 (:unicode "💅"))
    #(":name_badge:" 0 1 (:unicode "📛"))
    #(":namibia:" 0 1 (:unicode "🇳🇦"))
    #(":national_park:" 0 1 (:unicode "🏞️"))
    #(":nauru:" 0 1 (:unicode "🇳🇷"))
    #(":nauseated_face:" 0 1 (:unicode "🤢"))
    #(":nazar_amulet:" 0 1 (:unicode "🧿"))
    #(":necktie:" 0 1 (:unicode "👔"))
    #(":negative_squared_cross_mark:" 0 1 (:unicode "❎"))
    #(":nepal:" 0 1 (:unicode "🇳🇵"))
    #(":nerd_face:" 0 1 (:unicode "🤓"))
    #(":nest_with_eggs:" 0 1 (:unicode "🪺"))
    #(":nesting_dolls:" 0 1 (:unicode "🪆"))
    #(":netherlands:" 0 1 (:unicode "🇳🇱"))
    #(":neutral_face:" 0 1 (:unicode "😐"))
    #(":new:" 0 1 (:unicode "🆕"))
    #(":new_caledonia:" 0 1 (:unicode "🇳🇨"))
    #(":new_moon:" 0 1 (:unicode "🌑"))
    #(":new_moon_with_face:" 0 1 (:unicode "🌚"))
    #(":new_zealand:" 0 1 (:unicode "🇳🇿"))
    #(":newspaper:" 0 1 (:unicode "📰"))
    #(":newspaper_roll:" 0 1 (:unicode "🗞️"))
    #(":next_track_button:" 0 1 (:unicode "⏭️"))
    #(":ng:" 0 1 (:unicode "🆖"))
    #(":nicaragua:" 0 1 (:unicode "🇳🇮"))
    #(":niger:" 0 1 (:unicode "🇳🇪"))
    #(":nigeria:" 0 1 (:unicode "🇳🇬"))
    #(":night_with_stars:" 0 1 (:unicode "🌃"))
    #(":nine:" 0 1 (:unicode "9️⃣"))
    #(":ninja:" 0 1 (:unicode "🥷"))
    #(":niue:" 0 1 (:unicode "🇳🇺"))
    #(":no_bell:" 0 1 (:unicode "🔕"))
    #(":no_bicycles:" 0 1 (:unicode "🚳"))
    #(":no_entry:" 0 1 (:unicode "⛔"))
    #(":no_entry_sign:" 0 1 (:unicode "🚫"))
    #(":no_good:" 0 1 (:unicode "🙅"))
    #(":no_good_man:" 0 1 (:unicode "🙅‍♂️"))
    #(":no_good_woman:" 0 1 (:unicode "🙅‍♀️"))
    #(":no_mobile_phones:" 0 1 (:unicode "📵"))
    #(":no_mouth:" 0 1 (:unicode "😶"))
    #(":no_pedestrians:" 0 1 (:unicode "🚷"))
    #(":no_smoking:" 0 1 (:unicode "🚭"))
    #(":non-potable_water:" 0 1 (:unicode "🚱"))
    #(":norfolk_island:" 0 1 (:unicode "🇳🇫"))
    #(":north_korea:" 0 1 (:unicode "🇰🇵"))
    #(":northern_mariana_islands:" 0 1 (:unicode "🇲🇵"))
    #(":norway:" 0 1 (:unicode "🇳🇴"))
    #(":nose:" 0 1 (:unicode "👃"))
    #(":notebook:" 0 1 (:unicode "📓"))
    #(":notebook_with_decorative_cover:" 0 1 (:unicode "📔"))
    #(":notes:" 0 1 (:unicode "🎶"))
    #(":nut_and_bolt:" 0 1 (:unicode "🔩"))
    #(":o:" 0 1 (:unicode "⭕"))
    #(":o2:" 0 1 (:unicode "🅾️"))
    #(":ocean:" 0 1 (:unicode "🌊"))
    #(":octopus:" 0 1 (:unicode "🐙"))
    #(":oden:" 0 1 (:unicode "🍢"))
    #(":office:" 0 1 (:unicode "🏢"))
    #(":office_worker:" 0 1 (:unicode "🧑‍💼"))
    #(":oil_drum:" 0 1 (:unicode "🛢️"))
    #(":ok:" 0 1 (:unicode "🆗"))
    #(":ok_hand:" 0 1 (:unicode "👌"))
    #(":ok_man:" 0 1 (:unicode "🙆‍♂️"))
    #(":ok_person:" 0 1 (:unicode "🙆"))
    #(":ok_woman:" 0 1 (:unicode "🙆‍♀️"))
    #(":old_key:" 0 1 (:unicode "🗝️"))
    #(":older_adult:" 0 1 (:unicode "🧓"))
    #(":older_man:" 0 1 (:unicode "👴"))
    #(":older_woman:" 0 1 (:unicode "👵"))
    #(":olive:" 0 1 (:unicode "🫒"))
    #(":om:" 0 1 (:unicode "🕉️"))
    #(":oman:" 0 1 (:unicode "🇴🇲"))
    #(":on:" 0 1 (:unicode "🔛"))
    #(":oncoming_automobile:" 0 1 (:unicode "🚘"))
    #(":oncoming_bus:" 0 1 (:unicode "🚍"))
    #(":oncoming_police_car:" 0 1 (:unicode "🚔"))
    #(":oncoming_taxi:" 0 1 (:unicode "🚖"))
    #(":one:" 0 1 (:unicode "1️⃣"))
    #(":one_piece_swimsuit:" 0 1 (:unicode "🩱"))
    #(":onion:" 0 1 (:unicode "🧅"))
    #(":open_file_folder:" 0 1 (:unicode "📂"))
    #(":open_hands:" 0 1 (:unicode "👐"))
    #(":open_mouth:" 0 1 (:unicode "😮"))
    #(":open_umbrella:" 0 1 (:unicode "☂️"))
    #(":ophiuchus:" 0 1 (:unicode "⛎"))
    #(":orange_book:" 0 1 (:unicode "📙"))
    #(":orange_circle:" 0 1 (:unicode "🟠"))
    #(":orange_heart:" 0 1 (:unicode "🧡"))
    #(":orange_square:" 0 1 (:unicode "🟧"))
    #(":orangutan:" 0 1 (:unicode "🦧"))
    #(":orthodox_cross:" 0 1 (:unicode "☦️"))
    #(":otter:" 0 1 (:unicode "🦦"))
    #(":outbox_tray:" 0 1 (:unicode "📤"))
    #(":owl:" 0 1 (:unicode "🦉"))
    #(":ox:" 0 1 (:unicode "🐂"))
    #(":oyster:" 0 1 (:unicode "🦪"))
    #(":package:" 0 1 (:unicode "📦"))
    #(":page_facing_up:" 0 1 (:unicode "📄"))
    #(":page_with_curl:" 0 1 (:unicode "📃"))
    #(":pager:" 0 1 (:unicode "📟"))
    #(":paintbrush:" 0 1 (:unicode "🖌️"))
    #(":pakistan:" 0 1 (:unicode "🇵🇰"))
    #(":palau:" 0 1 (:unicode "🇵🇼"))
    #(":palestinian_territories:" 0 1 (:unicode "🇵🇸"))
    #(":palm_down_hand:" 0 1 (:unicode "🫳"))
    #(":palm_tree:" 0 1 (:unicode "🌴"))
    #(":palm_up_hand:" 0 1 (:unicode "🫴"))
    #(":palms_up_together:" 0 1 (:unicode "🤲"))
    #(":panama:" 0 1 (:unicode "🇵🇦"))
    #(":pancakes:" 0 1 (:unicode "🥞"))
    #(":panda_face:" 0 1 (:unicode "🐼"))
    #(":paperclip:" 0 1 (:unicode "📎"))
    #(":paperclips:" 0 1 (:unicode "🖇️"))
    #(":papua_new_guinea:" 0 1 (:unicode "🇵🇬"))
    #(":parachute:" 0 1 (:unicode "🪂"))
    #(":paraguay:" 0 1 (:unicode "🇵🇾"))
    #(":parasol_on_ground:" 0 1 (:unicode "⛱️"))
    #(":parking:" 0 1 (:unicode "🅿️"))
    #(":parrot:" 0 1 (:unicode "🦜"))
    #(":part_alternation_mark:" 0 1 (:unicode "〽️"))
    #(":partly_sunny:" 0 1 (:unicode "⛅"))
    #(":partying_face:" 0 1 (:unicode "🥳"))
    #(":passenger_ship:" 0 1 (:unicode "🛳️"))
    #(":passport_control:" 0 1 (:unicode "🛂"))
    #(":pause_button:" 0 1 (:unicode "⏸️"))
    #(":pea_pod:" 0 1 (:unicode "🫛"))
    #(":peace_symbol:" 0 1 (:unicode "☮️"))
    #(":peach:" 0 1 (:unicode "🍑"))
    #(":peacock:" 0 1 (:unicode "🦚"))
    #(":peanuts:" 0 1 (:unicode "🥜"))
    #(":pear:" 0 1 (:unicode "🍐"))
    #(":pen:" 0 1 (:unicode "🖊️"))
    #(":pencil2:" 0 1 (:unicode "✏️"))
    #(":penguin:" 0 1 (:unicode "🐧"))
    #(":pensive:" 0 1 (:unicode "😔"))
    #(":people_holding_hands:" 0 1 (:unicode "🧑‍🤝‍🧑"))
    #(":people_hugging:" 0 1 (:unicode "🫂"))
    #(":performing_arts:" 0 1 (:unicode "🎭"))
    #(":persevere:" 0 1 (:unicode "😣"))
    #(":person_bald:" 0 1 (:unicode "🧑‍🦲"))
    #(":person_curly_hair:" 0 1 (:unicode "🧑‍🦱"))
    #(":person_feeding_baby:" 0 1 (:unicode "🧑‍🍼"))
    #(":person_fencing:" 0 1 (:unicode "🤺"))
    #(":person_in_manual_wheelchair:" 0 1 (:unicode "🧑‍🦽"))
    #(":person_in_motorized_wheelchair:" 0 1 (:unicode "🧑‍🦼"))
    #(":person_in_tuxedo:" 0 1 (:unicode "🤵"))
    #(":person_red_hair:" 0 1 (:unicode "🧑‍🦰"))
    #(":person_white_hair:" 0 1 (:unicode "🧑‍🦳"))
    #(":person_with_crown:" 0 1 (:unicode "🫅"))
    #(":person_with_probing_cane:" 0 1 (:unicode "🧑‍🦯"))
    #(":person_with_turban:" 0 1 (:unicode "👳"))
    #(":person_with_veil:" 0 1 (:unicode "👰"))
    #(":peru:" 0 1 (:unicode "🇵🇪"))
    #(":petri_dish:" 0 1 (:unicode "🧫"))
    #(":philippines:" 0 1 (:unicode "🇵🇭"))
    #(":phone:" 0 1 (:unicode "☎️"))
    #(":pick:" 0 1 (:unicode "⛏️"))
    #(":pickup_truck:" 0 1 (:unicode "🛻"))
    #(":pie:" 0 1 (:unicode "🥧"))
    #(":pig:" 0 1 (:unicode "🐷"))
    #(":pig2:" 0 1 (:unicode "🐖"))
    #(":pig_nose:" 0 1 (:unicode "🐽"))
    #(":pill:" 0 1 (:unicode "💊"))
    #(":pilot:" 0 1 (:unicode "🧑‍✈️"))
    #(":pinata:" 0 1 (:unicode "🪅"))
    #(":pinched_fingers:" 0 1 (:unicode "🤌"))
    #(":pinching_hand:" 0 1 (:unicode "🤏"))
    #(":pineapple:" 0 1 (:unicode "🍍"))
    #(":ping_pong:" 0 1 (:unicode "🏓"))
    #(":pink_heart:" 0 1 (:unicode "🩷"))
    #(":pirate_flag:" 0 1 (:unicode "🏴‍☠️"))
    #(":pisces:" 0 1 (:unicode "♓"))
    #(":pitcairn_islands:" 0 1 (:unicode "🇵🇳"))
    #(":pizza:" 0 1 (:unicode "🍕"))
    #(":placard:" 0 1 (:unicode "🪧"))
    #(":place_of_worship:" 0 1 (:unicode "🛐"))
    #(":plate_with_cutlery:" 0 1 (:unicode "🍽️"))
    #(":play_or_pause_button:" 0 1 (:unicode "⏯️"))
    #(":playground_slide:" 0 1 (:unicode "🛝"))
    #(":pleading_face:" 0 1 (:unicode "🥺"))
    #(":plunger:" 0 1 (:unicode "🪠"))
    #(":point_down:" 0 1 (:unicode "👇"))
    #(":point_left:" 0 1 (:unicode "👈"))
    #(":point_right:" 0 1 (:unicode "👉"))
    #(":point_up:" 0 1 (:unicode "☝️"))
    #(":point_up_2:" 0 1 (:unicode "👆"))
    #(":poland:" 0 1 (:unicode "🇵🇱"))
    #(":polar_bear:" 0 1 (:unicode "🐻‍❄️"))
    #(":police_car:" 0 1 (:unicode "🚓"))
    #(":police_officer:" 0 1 (:unicode "👮"))
    #(":policeman:" 0 1 (:unicode "👮‍♂️"))
    #(":policewoman:" 0 1 (:unicode "👮‍♀️"))
    #(":poodle:" 0 1 (:unicode "🐩"))
    #(":popcorn:" 0 1 (:unicode "🍿"))
    #(":portugal:" 0 1 (:unicode "🇵🇹"))
    #(":post_office:" 0 1 (:unicode "🏣"))
    #(":postal_horn:" 0 1 (:unicode "📯"))
    #(":postbox:" 0 1 (:unicode "📮"))
    #(":potable_water:" 0 1 (:unicode "🚰"))
    #(":potato:" 0 1 (:unicode "🥔"))
    #(":potted_plant:" 0 1 (:unicode "🪴"))
    #(":pouch:" 0 1 (:unicode "👝"))
    #(":poultry_leg:" 0 1 (:unicode "🍗"))
    #(":pound:" 0 1 (:unicode "💷"))
    #(":pouring_liquid:" 0 1 (:unicode "🫗"))
    #(":pouting_cat:" 0 1 (:unicode "😾"))
    #(":pouting_face:" 0 1 (:unicode "🙎"))
    #(":pouting_man:" 0 1 (:unicode "🙎‍♂️"))
    #(":pouting_woman:" 0 1 (:unicode "🙎‍♀️"))
    #(":pray:" 0 1 (:unicode "🙏"))
    #(":prayer_beads:" 0 1 (:unicode "📿"))
    #(":pregnant_man:" 0 1 (:unicode "🫃"))
    #(":pregnant_person:" 0 1 (:unicode "🫄"))
    #(":pregnant_woman:" 0 1 (:unicode "🤰"))
    #(":pretzel:" 0 1 (:unicode "🥨"))
    #(":previous_track_button:" 0 1 (:unicode "⏮️"))
    #(":prince:" 0 1 (:unicode "🤴"))
    #(":princess:" 0 1 (:unicode "👸"))
    #(":printer:" 0 1 (:unicode "🖨️"))
    #(":probing_cane:" 0 1 (:unicode "🦯"))
    #(":puerto_rico:" 0 1 (:unicode "🇵🇷"))
    #(":purple_circle:" 0 1 (:unicode "🟣"))
    #(":purple_heart:" 0 1 (:unicode "💜"))
    #(":purple_square:" 0 1 (:unicode "🟪"))
    #(":purse:" 0 1 (:unicode "👛"))
    #(":pushpin:" 0 1 (:unicode "📌"))
    #(":put_litter_in_its_place:" 0 1 (:unicode "🚮"))
    #(":qatar:" 0 1 (:unicode "🇶🇦"))
    #(":question:" 0 1 (:unicode "❓"))
    #(":rabbit:" 0 1 (:unicode "🐰"))
    #(":rabbit2:" 0 1 (:unicode "🐇"))
    #(":raccoon:" 0 1 (:unicode "🦝"))
    #(":racehorse:" 0 1 (:unicode "🐎"))
    #(":racing_car:" 0 1 (:unicode "🏎️"))
    #(":radio:" 0 1 (:unicode "📻"))
    #(":radio_button:" 0 1 (:unicode "🔘"))
    #(":radioactive:" 0 1 (:unicode "☢️"))
    #(":rage:" 0 1 (:unicode "😡"))
    #(":railway_car:" 0 1 (:unicode "🚃"))
    #(":railway_track:" 0 1 (:unicode "🛤️"))
    #(":rainbow:" 0 1 (:unicode "🌈"))
    #(":rainbow_flag:" 0 1 (:unicode "🏳️‍🌈"))
    #(":raised_back_of_hand:" 0 1 (:unicode "🤚"))
    #(":raised_eyebrow:" 0 1 (:unicode "🤨"))
    #(":raised_hand_with_fingers_splayed:" 0 1 (:unicode "🖐️"))
    #(":raised_hands:" 0 1 (:unicode "🙌"))
    #(":raising_hand:" 0 1 (:unicode "🙋"))
    #(":raising_hand_man:" 0 1 (:unicode "🙋‍♂️"))
    #(":raising_hand_woman:" 0 1 (:unicode "🙋‍♀️"))
    #(":ram:" 0 1 (:unicode "🐏"))
    #(":ramen:" 0 1 (:unicode "🍜"))
    #(":rat:" 0 1 (:unicode "🐀"))
    #(":razor:" 0 1 (:unicode "🪒"))
    #(":receipt:" 0 1 (:unicode "🧾"))
    #(":record_button:" 0 1 (:unicode "⏺️"))
    #(":recycle:" 0 1 (:unicode "♻️"))
    #(":red_circle:" 0 1 (:unicode "🔴"))
    #(":red_envelope:" 0 1 (:unicode "🧧"))
    #(":red_haired_man:" 0 1 (:unicode "👨‍🦰"))
    #(":red_haired_woman:" 0 1 (:unicode "👩‍🦰"))
    #(":red_square:" 0 1 (:unicode "🟥"))
    #(":registered:" 0 1 (:unicode "®️"))
    #(":relaxed:" 0 1 (:unicode "☺️"))
    #(":relieved:" 0 1 (:unicode "😌"))
    #(":reminder_ribbon:" 0 1 (:unicode "🎗️"))
    #(":repeat:" 0 1 (:unicode "🔁"))
    #(":repeat_one:" 0 1 (:unicode "🔂"))
    #(":rescue_worker_helmet:" 0 1 (:unicode "⛑️"))
    #(":restroom:" 0 1 (:unicode "🚻"))
    #(":reunion:" 0 1 (:unicode "🇷🇪"))
    #(":revolving_hearts:" 0 1 (:unicode "💞"))
    #(":rewind:" 0 1 (:unicode "⏪"))
    #(":rhinoceros:" 0 1 (:unicode "🦏"))
    #(":ribbon:" 0 1 (:unicode "🎀"))
    #(":rice:" 0 1 (:unicode "🍚"))
    #(":rice_ball:" 0 1 (:unicode "🍙"))
    #(":rice_cracker:" 0 1 (:unicode "🍘"))
    #(":rice_scene:" 0 1 (:unicode "🎑"))
    #(":right_anger_bubble:" 0 1 (:unicode "🗯️"))
    #(":rightwards_hand:" 0 1 (:unicode "🫱"))
    #(":rightwards_pushing_hand:" 0 1 (:unicode "🫸"))
    #(":ring:" 0 1 (:unicode "💍"))
    #(":ring_buoy:" 0 1 (:unicode "🛟"))
    #(":ringed_planet:" 0 1 (:unicode "🪐"))
    #(":robot:" 0 1 (:unicode "🤖"))
    #(":rock:" 0 1 (:unicode "🪨"))
    #(":rocket:" 0 1 (:unicode "🚀"))
    #(":rofl:" 0 1 (:unicode "🤣"))
    #(":roll_eyes:" 0 1 (:unicode "🙄"))
    #(":roll_of_paper:" 0 1 (:unicode "🧻"))
    #(":roller_coaster:" 0 1 (:unicode "🎢"))
    #(":roller_skate:" 0 1 (:unicode "🛼"))
    #(":romania:" 0 1 (:unicode "🇷🇴"))
    #(":rooster:" 0 1 (:unicode "🐓"))
    #(":rose:" 0 1 (:unicode "🌹"))
    #(":rosette:" 0 1 (:unicode "🏵️"))
    #(":rotating_light:" 0 1 (:unicode "🚨"))
    #(":round_pushpin:" 0 1 (:unicode "📍"))
    #(":rowboat:" 0 1 (:unicode "🚣"))
    #(":rowing_man:" 0 1 (:unicode "🚣‍♂️"))
    #(":rowing_woman:" 0 1 (:unicode "🚣‍♀️"))
    #(":ru:" 0 1 (:unicode "🇷🇺"))
    #(":rugby_football:" 0 1 (:unicode "🏉"))
    #(":runner:" 0 1 (:unicode "🏃"))
    #(":running_man:" 0 1 (:unicode "🏃‍♂️"))
    #(":running_shirt_with_sash:" 0 1 (:unicode "🎽"))
    #(":running_woman:" 0 1 (:unicode "🏃‍♀️"))
    #(":rwanda:" 0 1 (:unicode "🇷🇼"))
    #(":sa:" 0 1 (:unicode "🈂️"))
    #(":safety_pin:" 0 1 (:unicode "🧷"))
    #(":safety_vest:" 0 1 (:unicode "🦺"))
    #(":sagittarius:" 0 1 (:unicode "♐"))
    #(":sake:" 0 1 (:unicode "🍶"))
    #(":salt:" 0 1 (:unicode "🧂"))
    #(":saluting_face:" 0 1 (:unicode "🫡"))
    #(":samoa:" 0 1 (:unicode "🇼🇸"))
    #(":san_marino:" 0 1 (:unicode "🇸🇲"))
    #(":sandal:" 0 1 (:unicode "👡"))
    #(":sandwich:" 0 1 (:unicode "🥪"))
    #(":santa:" 0 1 (:unicode "🎅"))
    #(":sao_tome_principe:" 0 1 (:unicode "🇸🇹"))
    #(":sari:" 0 1 (:unicode "🥻"))
    #(":satellite:" 0 1 (:unicode "📡"))
    #(":saudi_arabia:" 0 1 (:unicode "🇸🇦"))
    #(":sauna_man:" 0 1 (:unicode "🧖‍♂️"))
    #(":sauna_person:" 0 1 (:unicode "🧖"))
    #(":sauna_woman:" 0 1 (:unicode "🧖‍♀️"))
    #(":sauropod:" 0 1 (:unicode "🦕"))
    #(":saxophone:" 0 1 (:unicode "🎷"))
    #(":scarf:" 0 1 (:unicode "🧣"))
    #(":school:" 0 1 (:unicode "🏫"))
    #(":school_satchel:" 0 1 (:unicode "🎒"))
    #(":scientist:" 0 1 (:unicode "🧑‍🔬"))
    #(":scissors:" 0 1 (:unicode "✂️"))
    #(":scorpion:" 0 1 (:unicode "🦂"))
    #(":scorpius:" 0 1 (:unicode "♏"))
    #(":scotland:" 0 1 (:unicode "🏴󠁧󠁢󠁳󠁣󠁴󠁿"))
    #(":scream:" 0 1 (:unicode "😱"))
    #(":scream_cat:" 0 1 (:unicode "🙀"))
    #(":screwdriver:" 0 1 (:unicode "🪛"))
    #(":scroll:" 0 1 (:unicode "📜"))
    #(":seal:" 0 1 (:unicode "🦭"))
    #(":seat:" 0 1 (:unicode "💺"))
    #(":secret:" 0 1 (:unicode "㊙️"))
    #(":see_no_evil:" 0 1 (:unicode "🙈"))
    #(":seedling:" 0 1 (:unicode "🌱"))
    #(":selfie:" 0 1 (:unicode "🤳"))
    #(":senegal:" 0 1 (:unicode "🇸🇳"))
    #(":serbia:" 0 1 (:unicode "🇷🇸"))
    #(":service_dog:" 0 1 (:unicode "🐕‍🦺"))
    #(":seven:" 0 1 (:unicode "7️⃣"))
    #(":sewing_needle:" 0 1 (:unicode "🪡"))
    #(":seychelles:" 0 1 (:unicode "🇸🇨"))
    #(":shaking_face:" 0 1 (:unicode "🫨"))
    #(":shallow_pan_of_food:" 0 1 (:unicode "🥘"))
    #(":shamrock:" 0 1 (:unicode "☘️"))
    #(":shark:" 0 1 (:unicode "🦈"))
    #(":shaved_ice:" 0 1 (:unicode "🍧"))
    #(":sheep:" 0 1 (:unicode "🐑"))
    #(":shell:" 0 1 (:unicode "🐚"))
    #(":shield:" 0 1 (:unicode "🛡️"))
    #(":shinto_shrine:" 0 1 (:unicode "⛩️"))
    #(":ship:" 0 1 (:unicode "🚢"))
    #(":shirt:" 0 1 (:unicode "👕"))
    #(":shopping:" 0 1 (:unicode "🛍️"))
    #(":shopping_cart:" 0 1 (:unicode "🛒"))
    #(":shorts:" 0 1 (:unicode "🩳"))
    #(":shower:" 0 1 (:unicode "🚿"))
    #(":shrimp:" 0 1 (:unicode "🦐"))
    #(":shrug:" 0 1 (:unicode "🤷"))
    #(":shushing_face:" 0 1 (:unicode "🤫"))
    #(":sierra_leone:" 0 1 (:unicode "🇸🇱"))
    #(":signal_strength:" 0 1 (:unicode "📶"))
    #(":singapore:" 0 1 (:unicode "🇸🇬"))
    #(":singer:" 0 1 (:unicode "🧑‍🎤"))
    #(":sint_maarten:" 0 1 (:unicode "🇸🇽"))
    #(":six:" 0 1 (:unicode "6️⃣"))
    #(":six_pointed_star:" 0 1 (:unicode "🔯"))
    #(":skateboard:" 0 1 (:unicode "🛹"))
    #(":ski:" 0 1 (:unicode "🎿"))
    #(":skier:" 0 1 (:unicode "⛷️"))
    #(":skin-tone-1:" 0 1 (:unicode "🏻"))
    #(":skin-tone-2:" 0 1 (:unicode "🏻"))
    #(":skin-tone-3:" 0 1 (:unicode "🏽"))
    #(":skin-tone-4:" 0 1 (:unicode "🏾"))
    #(":skin-tone-5:" 0 1 (:unicode "🏿"))
    #(":skull:" 0 1 (:unicode "💀"))
    #(":skull_and_crossbones:" 0 1 (:unicode "☠️"))
    #(":skunk:" 0 1 (:unicode "🦨"))
    #(":sled:" 0 1 (:unicode "🛷"))
    #(":sleeping:" 0 1 (:unicode "😴"))
    #(":sleeping_bed:" 0 1 (:unicode "🛌"))
    #(":sleepy:" 0 1 (:unicode "😪"))
    #(":slightly_frowning_face:" 0 1 (:unicode "🙁"))
    #(":slightly_smiling_face:" 0 1 (:unicode "🙂"))
    #(":slot_machine:" 0 1 (:unicode "🎰"))
    #(":sloth:" 0 1 (:unicode "🦥"))
    #(":slovakia:" 0 1 (:unicode "🇸🇰"))
    #(":slovenia:" 0 1 (:unicode "🇸🇮"))
    #(":small_airplane:" 0 1 (:unicode "🛩️"))
    #(":small_blue_diamond:" 0 1 (:unicode "🔹"))
    #(":small_orange_diamond:" 0 1 (:unicode "🔸"))
    #(":small_red_triangle:" 0 1 (:unicode "🔺"))
    #(":small_red_triangle_down:" 0 1 (:unicode "🔻"))
    #(":smile:" 0 1 (:unicode "😄"))
    #(":smile_cat:" 0 1 (:unicode "😸"))
    #(":smiley:" 0 1 (:unicode "😃"))
    #(":smiley_cat:" 0 1 (:unicode "😺"))
    #(":smiling_face_with_tear:" 0 1 (:unicode "🥲"))
    #(":smiling_face_with_three_hearts:" 0 1 (:unicode "🥰"))
    #(":smiling_imp:" 0 1 (:unicode "😈"))
    #(":smirk:" 0 1 (:unicode "😏"))
    #(":smirk_cat:" 0 1 (:unicode "😼"))
    #(":smoking:" 0 1 (:unicode "🚬"))
    #(":snail:" 0 1 (:unicode "🐌"))
    #(":snake:" 0 1 (:unicode "🐍"))
    #(":sneezing_face:" 0 1 (:unicode "🤧"))
    #(":snowboarder:" 0 1 (:unicode "🏂"))
    #(":snowflake:" 0 1 (:unicode "❄️"))
    #(":snowman:" 0 1 (:unicode "⛄"))
    #(":snowman_with_snow:" 0 1 (:unicode "☃️"))
    #(":soap:" 0 1 (:unicode "🧼"))
    #(":sob:" 0 1 (:unicode "😭"))
    #(":soccer:" 0 1 (:unicode "⚽"))
    #(":socks:" 0 1 (:unicode "🧦"))
    #(":softball:" 0 1 (:unicode "🥎"))
    #(":solomon_islands:" 0 1 (:unicode "🇸🇧"))
    #(":somalia:" 0 1 (:unicode "🇸🇴"))
    #(":soon:" 0 1 (:unicode "🔜"))
    #(":sos:" 0 1 (:unicode "🆘"))
    #(":sound:" 0 1 (:unicode "🔉"))
    #(":south_africa:" 0 1 (:unicode "🇿🇦"))
    #(":south_georgia_south_sandwich_islands:" 0 1 (:unicode "🇬🇸"))
    #(":south_sudan:" 0 1 (:unicode "🇸🇸"))
    #(":space_invader:" 0 1 (:unicode "👾"))
    #(":spades:" 0 1 (:unicode "♠️"))
    #(":spaghetti:" 0 1 (:unicode "🍝"))
    #(":sparkle:" 0 1 (:unicode "❇️"))
    #(":sparkler:" 0 1 (:unicode "🎇"))
    #(":sparkles:" 0 1 (:unicode "✨"))
    #(":sparkling_heart:" 0 1 (:unicode "💖"))
    #(":speak_no_evil:" 0 1 (:unicode "🙊"))
    #(":speaker:" 0 1 (:unicode "🔈"))
    #(":speaking_head:" 0 1 (:unicode "🗣️"))
    #(":speech_balloon:" 0 1 (:unicode "💬"))
    #(":speedboat:" 0 1 (:unicode "🚤"))
    #(":spider:" 0 1 (:unicode "🕷️"))
    #(":spider_web:" 0 1 (:unicode "🕸️"))
    #(":spiral_calendar:" 0 1 (:unicode "🗓️"))
    #(":spiral_notepad:" 0 1 (:unicode "🗒️"))
    #(":sponge:" 0 1 (:unicode "🧽"))
    #(":spoon:" 0 1 (:unicode "🥄"))
    #(":squid:" 0 1 (:unicode "🦑"))
    #(":sri_lanka:" 0 1 (:unicode "🇱🇰"))
    #(":st_barthelemy:" 0 1 (:unicode "🇧🇱"))
    #(":st_helena:" 0 1 (:unicode "🇸🇭"))
    #(":st_kitts_nevis:" 0 1 (:unicode "🇰🇳"))
    #(":st_lucia:" 0 1 (:unicode "🇱🇨"))
    #(":st_martin:" 0 1 (:unicode "🇲🇫"))
    #(":st_pierre_miquelon:" 0 1 (:unicode "🇵🇲"))
    #(":st_vincent_grenadines:" 0 1 (:unicode "🇻🇨"))
    #(":stadium:" 0 1 (:unicode "🏟️"))
    #(":standing_man:" 0 1 (:unicode "🧍‍♂️"))
    #(":standing_person:" 0 1 (:unicode "🧍"))
    #(":standing_woman:" 0 1 (:unicode "🧍‍♀️"))
    #(":star:" 0 1 (:unicode "⭐"))
    #(":star2:" 0 1 (:unicode "🌟"))
    #(":star_and_crescent:" 0 1 (:unicode "☪️"))
    #(":star_of_david:" 0 1 (:unicode "✡️"))
    #(":star_struck:" 0 1 (:unicode "🤩"))
    #(":stars:" 0 1 (:unicode "🌠"))
    #(":station:" 0 1 (:unicode "🚉"))
    #(":statue_of_liberty:" 0 1 (:unicode "🗽"))
    #(":steam_locomotive:" 0 1 (:unicode "🚂"))
    #(":stethoscope:" 0 1 (:unicode "🩺"))
    #(":stew:" 0 1 (:unicode "🍲"))
    #(":stop_button:" 0 1 (:unicode "⏹️"))
    #(":stop_sign:" 0 1 (:unicode "🛑"))
    #(":stopwatch:" 0 1 (:unicode "⏱️"))
    #(":straight_ruler:" 0 1 (:unicode "📏"))
    #(":strawberry:" 0 1 (:unicode "🍓"))
    #(":stuck_out_tongue:" 0 1 (:unicode "😛"))
    #(":stuck_out_tongue_closed_eyes:" 0 1 (:unicode "😝"))
    #(":stuck_out_tongue_winking_eye:" 0 1 (:unicode "😜"))
    #(":student:" 0 1 (:unicode "🧑‍🎓"))
    #(":studio_microphone:" 0 1 (:unicode "🎙️"))
    #(":stuffed_flatbread:" 0 1 (:unicode "🥙"))
    #(":sudan:" 0 1 (:unicode "🇸🇩"))
    #(":sun_behind_large_cloud:" 0 1 (:unicode "🌥️"))
    #(":sun_behind_rain_cloud:" 0 1 (:unicode "🌦️"))
    #(":sun_behind_small_cloud:" 0 1 (:unicode "🌤️"))
    #(":sun_with_face:" 0 1 (:unicode "🌞"))
    #(":sunflower:" 0 1 (:unicode "🌻"))
    #(":sunglasses:" 0 1 (:unicode "😎"))
    #(":sunny:" 0 1 (:unicode "☀️"))
    #(":sunrise:" 0 1 (:unicode "🌅"))
    #(":sunrise_over_mountains:" 0 1 (:unicode "🌄"))
    #(":superhero:" 0 1 (:unicode "🦸"))
    #(":superhero_man:" 0 1 (:unicode "🦸‍♂️"))
    #(":superhero_woman:" 0 1 (:unicode "🦸‍♀️"))
    #(":supervillain:" 0 1 (:unicode "🦹"))
    #(":supervillain_man:" 0 1 (:unicode "🦹‍♂️"))
    #(":supervillain_woman:" 0 1 (:unicode "🦹‍♀️"))
    #(":surfer:" 0 1 (:unicode "🏄"))
    #(":surfing_man:" 0 1 (:unicode "🏄‍♂️"))
    #(":surfing_woman:" 0 1 (:unicode "🏄‍♀️"))
    #(":suriname:" 0 1 (:unicode "🇸🇷"))
    #(":sushi:" 0 1 (:unicode "🍣"))
    #(":suspension_railway:" 0 1 (:unicode "🚟"))
    #(":svalbard_jan_mayen:" 0 1 (:unicode "🇸🇯"))
    #(":swan:" 0 1 (:unicode "🦢"))
    #(":swaziland:" 0 1 (:unicode "🇸🇿"))
    #(":sweat:" 0 1 (:unicode "😓"))
    #(":sweat_drops:" 0 1 (:unicode "💦"))
    #(":sweat_smile:" 0 1 (:unicode "😅"))
    #(":sweden:" 0 1 (:unicode "🇸🇪"))
    #(":sweet_potato:" 0 1 (:unicode "🍠"))
    #(":swim_brief:" 0 1 (:unicode "🩲"))
    #(":swimmer:" 0 1 (:unicode "🏊"))
    #(":swimming_man:" 0 1 (:unicode "🏊‍♂️"))
    #(":swimming_woman:" 0 1 (:unicode "🏊‍♀️"))
    #(":switzerland:" 0 1 (:unicode "🇨🇭"))
    #(":symbols:" 0 1 (:unicode "🔣"))
    #(":synagogue:" 0 1 (:unicode "🕍"))
    #(":syria:" 0 1 (:unicode "🇸🇾"))
    #(":syringe:" 0 1 (:unicode "💉"))
    #(":t-rex:" 0 1 (:unicode "🦖"))
    #(":taco:" 0 1 (:unicode "🌮"))
    #(":tada:" 0 1 (:unicode "🎉"))
    #(":taiwan:" 0 1 (:unicode "🇹🇼"))
    #(":tajikistan:" 0 1 (:unicode "🇹🇯"))
    #(":takeout_box:" 0 1 (:unicode "🥡"))
    #(":tamale:" 0 1 (:unicode "🫔"))
    #(":tanabata_tree:" 0 1 (:unicode "🎋"))
    #(":tangerine:" 0 1 (:unicode "🍊"))
    #(":tanzania:" 0 1 (:unicode "🇹🇿"))
    #(":taurus:" 0 1 (:unicode "♉"))
    #(":taxi:" 0 1 (:unicode "🚕"))
    #(":tea:" 0 1 (:unicode "🍵"))
    #(":teacher:" 0 1 (:unicode "🧑‍🏫"))
    #(":teapot:" 0 1 (:unicode "🫖"))
    #(":technologist:" 0 1 (:unicode "🧑‍💻"))
    #(":teddy_bear:" 0 1 (:unicode "🧸"))
    #(":telephone_receiver:" 0 1 (:unicode "📞"))
    #(":telescope:" 0 1 (:unicode "🔭"))
    #(":tennis:" 0 1 (:unicode "🎾"))
    #(":tent:" 0 1 (:unicode "⛺"))
    #(":test_tube:" 0 1 (:unicode "🧪"))
    #(":thailand:" 0 1 (:unicode "🇹🇭"))
    #(":thermometer:" 0 1 (:unicode "🌡️"))
    #(":thinking:" 0 1 (:unicode "🤔"))
    #(":thong_sandal:" 0 1 (:unicode "🩴"))
    #(":thought_balloon:" 0 1 (:unicode "💭"))
    #(":thread:" 0 1 (:unicode "🧵"))
    #(":three:" 0 1 (:unicode "3️⃣"))
    #(":ticket:" 0 1 (:unicode "🎫"))
    #(":tickets:" 0 1 (:unicode "🎟️"))
    #(":tiger:" 0 1 (:unicode "🐯"))
    #(":tiger2:" 0 1 (:unicode "🐅"))
    #(":timer_clock:" 0 1 (:unicode "⏲️"))
    #(":timor_leste:" 0 1 (:unicode "🇹🇱"))
    #(":tipping_hand_man:" 0 1 (:unicode "💁‍♂️"))
    #(":tipping_hand_person:" 0 1 (:unicode "💁"))
    #(":tipping_hand_woman:" 0 1 (:unicode "💁‍♀️"))
    #(":tired_face:" 0 1 (:unicode "😫"))
    #(":tm:" 0 1 (:unicode "™️"))
    #(":togo:" 0 1 (:unicode "🇹🇬"))
    #(":toilet:" 0 1 (:unicode "🚽"))
    #(":tokelau:" 0 1 (:unicode "🇹🇰"))
    #(":tokyo_tower:" 0 1 (:unicode "🗼"))
    #(":tomato:" 0 1 (:unicode "🍅"))
    #(":tonga:" 0 1 (:unicode "🇹🇴"))
    #(":tongue:" 0 1 (:unicode "👅"))
    #(":toolbox:" 0 1 (:unicode "🧰"))
    #(":tooth:" 0 1 (:unicode "🦷"))
    #(":toothbrush:" 0 1 (:unicode "🪥"))
    #(":top:" 0 1 (:unicode "🔝"))
    #(":tophat:" 0 1 (:unicode "🎩"))
    #(":tornado:" 0 1 (:unicode "🌪️"))
    #(":tr:" 0 1 (:unicode "🇹🇷"))
    #(":trackball:" 0 1 (:unicode "🖲️"))
    #(":tractor:" 0 1 (:unicode "🚜"))
    #(":traffic_light:" 0 1 (:unicode "🚥"))
    #(":train:" 0 1 (:unicode "🚋"))
    #(":train2:" 0 1 (:unicode "🚆"))
    #(":tram:" 0 1 (:unicode "🚊"))
    #(":transgender_flag:" 0 1 (:unicode "🏳️‍⚧️"))
    #(":transgender_symbol:" 0 1 (:unicode "⚧️"))
    #(":triangular_flag_on_post:" 0 1 (:unicode "🚩"))
    #(":triangular_ruler:" 0 1 (:unicode "📐"))
    #(":trident:" 0 1 (:unicode "🔱"))
    #(":trinidad_tobago:" 0 1 (:unicode "🇹🇹"))
    #(":tristan_da_cunha:" 0 1 (:unicode "🇹🇦"))
    #(":triumph:" 0 1 (:unicode "😤"))
    #(":troll:" 0 1 (:unicode "🧌"))
    #(":trolleybus:" 0 1 (:unicode "🚎"))
    #(":trophy:" 0 1 (:unicode "🏆"))
    #(":tropical_drink:" 0 1 (:unicode "🍹"))
    #(":tropical_fish:" 0 1 (:unicode "🐠"))
    #(":truck:" 0 1 (:unicode "🚚"))
    #(":trumpet:" 0 1 (:unicode "🎺"))
    #(":tulip:" 0 1 (:unicode "🌷"))
    #(":tumbler_glass:" 0 1 (:unicode "🥃"))
    #(":tunisia:" 0 1 (:unicode "🇹🇳"))
    #(":turkey:" 0 1 (:unicode "🦃"))
    #(":turkmenistan:" 0 1 (:unicode "🇹🇲"))
    #(":turks_caicos_islands:" 0 1 (:unicode "🇹🇨"))
    #(":turtle:" 0 1 (:unicode "🐢"))
    #(":tuvalu:" 0 1 (:unicode "🇹🇻"))
    #(":tv:" 0 1 (:unicode "📺"))
    #(":twisted_rightwards_arrows:" 0 1 (:unicode "🔀"))
    #(":two:" 0 1 (:unicode "2️⃣"))
    #(":two_hearts:" 0 1 (:unicode "💕"))
    #(":two_men_holding_hands:" 0 1 (:unicode "👬"))
    #(":two_women_holding_hands:" 0 1 (:unicode "👭"))
    #(":u5272:" 0 1 (:unicode "🈹"))
    #(":u5408:" 0 1 (:unicode "🈴"))
    #(":u55b6:" 0 1 (:unicode "🈺"))
    #(":u6307:" 0 1 (:unicode "🈯"))
    #(":u6708:" 0 1 (:unicode "🈷️"))
    #(":u6709:" 0 1 (:unicode "🈶"))
    #(":u6e80:" 0 1 (:unicode "🈵"))
    #(":u7121:" 0 1 (:unicode "🈚"))
    #(":u7533:" 0 1 (:unicode "🈸"))
    #(":u7981:" 0 1 (:unicode "🈲"))
    #(":u7a7a:" 0 1 (:unicode "🈳"))
    #(":uganda:" 0 1 (:unicode "🇺🇬"))
    #(":ukraine:" 0 1 (:unicode "🇺🇦"))
    #(":umbrella:" 0 1 (:unicode "☔"))
    #(":unamused:" 0 1 (:unicode "😒"))
    #(":underage:" 0 1 (:unicode "🔞"))
    #(":unicorn:" 0 1 (:unicode "🦄"))
    #(":united_arab_emirates:" 0 1 (:unicode "🇦🇪"))
    #(":united_nations:" 0 1 (:unicode "🇺🇳"))
    #(":unlock:" 0 1 (:unicode "🔓"))
    #(":up:" 0 1 (:unicode "🆙"))
    #(":upside_down_face:" 0 1 (:unicode "🙃"))
    #(":uruguay:" 0 1 (:unicode "🇺🇾"))
    #(":us:" 0 1 (:unicode "🇺🇸"))
    #(":us_outlying_islands:" 0 1 (:unicode "🇺🇲"))
    #(":us_virgin_islands:" 0 1 (:unicode "🇻🇮"))
    #(":uzbekistan:" 0 1 (:unicode "🇺🇿"))
    #(":v:" 0 1 (:unicode "✌️"))
    #(":vampire:" 0 1 (:unicode "🧛"))
    #(":vampire_man:" 0 1 (:unicode "🧛‍♂️"))
    #(":vampire_woman:" 0 1 (:unicode "🧛‍♀️"))
    #(":vanuatu:" 0 1 (:unicode "🇻🇺"))
    #(":vatican_city:" 0 1 (:unicode "🇻🇦"))
    #(":venezuela:" 0 1 (:unicode "🇻🇪"))
    #(":vertical_traffic_light:" 0 1 (:unicode "🚦"))
    #(":vhs:" 0 1 (:unicode "📼"))
    #(":vibration_mode:" 0 1 (:unicode "📳"))
    #(":video_camera:" 0 1 (:unicode "📹"))
    #(":video_game:" 0 1 (:unicode "🎮"))
    #(":vietnam:" 0 1 (:unicode "🇻🇳"))
    #(":violin:" 0 1 (:unicode "🎻"))
    #(":virgo:" 0 1 (:unicode "♍"))
    #(":volcano:" 0 1 (:unicode "🌋"))
    #(":volleyball:" 0 1 (:unicode "🏐"))
    #(":vomiting_face:" 0 1 (:unicode "🤮"))
    #(":vs:" 0 1 (:unicode "🆚"))
    #(":vulcan_salute:" 0 1 (:unicode "🖖"))
    #(":waffle:" 0 1 (:unicode "🧇"))
    #(":wales:" 0 1 (:unicode "🏴󠁧󠁢󠁷󠁬󠁳󠁿"))
    #(":walking:" 0 1 (:unicode "🚶"))
    #(":walking_man:" 0 1 (:unicode "🚶‍♂️"))
    #(":walking_woman:" 0 1 (:unicode "🚶‍♀️"))
    #(":wallis_futuna:" 0 1 (:unicode "🇼🇫"))
    #(":waning_crescent_moon:" 0 1 (:unicode "🌘"))
    #(":waning_gibbous_moon:" 0 1 (:unicode "🌖"))
    #(":warning:" 0 1 (:unicode "⚠️"))
    #(":wastebasket:" 0 1 (:unicode "🗑️"))
    #(":watch:" 0 1 (:unicode "⌚"))
    #(":water_buffalo:" 0 1 (:unicode "🐃"))
    #(":water_polo:" 0 1 (:unicode "🤽"))
    #(":watermelon:" 0 1 (:unicode "🍉"))
    #(":wave:" 0 1 (:unicode "👋"))
    #(":wavy_dash:" 0 1 (:unicode "〰️"))
    #(":waxing_crescent_moon:" 0 1 (:unicode "🌒"))
    #(":wc:" 0 1 (:unicode "🚾"))
    #(":weary:" 0 1 (:unicode "😩"))
    #(":wedding:" 0 1 (:unicode "💒"))
    #(":weight_lifting:" 0 1 (:unicode "🏋️"))
    #(":weight_lifting_man:" 0 1 (:unicode "🏋️‍♂️"))
    #(":weight_lifting_woman:" 0 1 (:unicode "🏋️‍♀️"))
    #(":western_sahara:" 0 1 (:unicode "🇪🇭"))
    #(":whale:" 0 1 (:unicode "🐳"))
    #(":whale2:" 0 1 (:unicode "🐋"))
    #(":wheel:" 0 1 (:unicode "🛞"))
    #(":wheel_of_dharma:" 0 1 (:unicode "☸️"))
    #(":wheelchair:" 0 1 (:unicode "♿"))
    #(":white_check_mark:" 0 1 (:unicode "✅"))
    #(":white_circle:" 0 1 (:unicode "⚪"))
    #(":white_flag:" 0 1 (:unicode "🏳️"))
    #(":white_flower:" 0 1 (:unicode "💮"))
    #(":white_haired_man:" 0 1 (:unicode "👨‍🦳"))
    #(":white_haired_woman:" 0 1 (:unicode "👩‍🦳"))
    #(":white_heart:" 0 1 (:unicode "🤍"))
    #(":white_large_square:" 0 1 (:unicode "⬜"))
    #(":white_medium_small_square:" 0 1 (:unicode "◽"))
    #(":white_medium_square:" 0 1 (:unicode "◻️"))
    #(":white_small_square:" 0 1 (:unicode "▫️"))
    #(":white_square_button:" 0 1 (:unicode "🔳"))
    #(":wilted_flower:" 0 1 (:unicode "🥀"))
    #(":wind_chime:" 0 1 (:unicode "🎐"))
    #(":wind_face:" 0 1 (:unicode "🌬️"))
    #(":window:" 0 1 (:unicode "🪟"))
    #(":wine_glass:" 0 1 (:unicode "🍷"))
    #(":wing:" 0 1 (:unicode "🪽"))
    #(":wink:" 0 1 (:unicode "😉"))
    #(":wireless:" 0 1 (:unicode "🛜"))
    #(":wolf:" 0 1 (:unicode "🐺"))
    #(":woman:" 0 1 (:unicode "👩"))
    #(":woman_artist:" 0 1 (:unicode "👩‍🎨"))
    #(":woman_astronaut:" 0 1 (:unicode "👩‍🚀"))
    #(":woman_beard:" 0 1 (:unicode "🧔‍♀️"))
    #(":woman_cartwheeling:" 0 1 (:unicode "🤸‍♀️"))
    #(":woman_cook:" 0 1 (:unicode "👩‍🍳"))
    #(":woman_dancing:" 0 1 (:unicode "💃"))
    #(":woman_facepalming:" 0 1 (:unicode "🤦‍♀️"))
    #(":woman_factory_worker:" 0 1 (:unicode "👩‍🏭"))
    #(":woman_farmer:" 0 1 (:unicode "👩‍🌾"))
    #(":woman_feeding_baby:" 0 1 (:unicode "👩‍🍼"))
    #(":woman_firefighter:" 0 1 (:unicode "👩‍🚒"))
    #(":woman_health_worker:" 0 1 (:unicode "👩‍⚕️"))
    #(":woman_in_manual_wheelchair:" 0 1 (:unicode "👩‍🦽"))
    #(":woman_in_motorized_wheelchair:" 0 1 (:unicode "👩‍🦼"))
    #(":woman_in_tuxedo:" 0 1 (:unicode "🤵‍♀️"))
    #(":woman_judge:" 0 1 (:unicode "👩‍⚖️"))
    #(":woman_juggling:" 0 1 (:unicode "🤹‍♀️"))
    #(":woman_mechanic:" 0 1 (:unicode "👩‍🔧"))
    #(":woman_office_worker:" 0 1 (:unicode "👩‍💼"))
    #(":woman_pilot:" 0 1 (:unicode "👩‍✈️"))
    #(":woman_playing_handball:" 0 1 (:unicode "🤾‍♀️"))
    #(":woman_playing_water_polo:" 0 1 (:unicode "🤽‍♀️"))
    #(":woman_scientist:" 0 1 (:unicode "👩‍🔬"))
    #(":woman_shrugging:" 0 1 (:unicode "🤷‍♀️"))
    #(":woman_singer:" 0 1 (:unicode "👩‍🎤"))
    #(":woman_student:" 0 1 (:unicode "👩‍🎓"))
    #(":woman_teacher:" 0 1 (:unicode "👩‍🏫"))
    #(":woman_technologist:" 0 1 (:unicode "👩‍💻"))
    #(":woman_with_headscarf:" 0 1 (:unicode "🧕"))
    #(":woman_with_probing_cane:" 0 1 (:unicode "👩‍🦯"))
    #(":woman_with_turban:" 0 1 (:unicode "👳‍♀️"))
    #(":woman_with_veil:" 0 1 (:unicode "👰‍♀️"))
    #(":womans_clothes:" 0 1 (:unicode "👚"))
    #(":womans_hat:" 0 1 (:unicode "👒"))
    #(":women_wrestling:" 0 1 (:unicode "🤼‍♀️"))
    #(":womens:" 0 1 (:unicode "🚺"))
    #(":wood:" 0 1 (:unicode "🪵"))
    #(":woozy_face:" 0 1 (:unicode "🥴"))
    #(":world_map:" 0 1 (:unicode "🗺️"))
    #(":worm:" 0 1 (:unicode "🪱"))
    #(":worried:" 0 1 (:unicode "😟"))
    #(":wrench:" 0 1 (:unicode "🔧"))
    #(":wrestling:" 0 1 (:unicode "🤼"))
    #(":writing_hand:" 0 1 (:unicode "✍️"))
    #(":x:" 0 1 (:unicode "❌"))
    #(":x_ray:" 0 1 (:unicode "🩻"))
    #(":yarn:" 0 1 (:unicode "🧶"))
    #(":yawning_face:" 0 1 (:unicode "🥱"))
    #(":yellow_circle:" 0 1 (:unicode "🟡"))
    #(":yellow_heart:" 0 1 (:unicode "💛"))
    #(":yellow_square:" 0 1 (:unicode "🟨"))
    #(":yemen:" 0 1 (:unicode "🇾🇪"))
    #(":yen:" 0 1 (:unicode "💴"))
    #(":yin_yang:" 0 1 (:unicode "☯️"))
    #(":yo_yo:" 0 1 (:unicode "🪀"))
    #(":yum:" 0 1 (:unicode "😋"))
    #(":zambia:" 0 1 (:unicode "🇿🇲"))
    #(":zany_face:" 0 1 (:unicode "🤪"))
    #(":zap:" 0 1 (:unicode "⚡"))
    #(":zebra:" 0 1 (:unicode "🦓"))
    #(":zero:" 0 1 (:unicode "0️⃣"))
    #(":zimbabwe:" 0 1 (:unicode "🇿🇼"))
    #(":zipper_mouth_face:" 0 1 (:unicode "🤐"))
    #(":zombie:" 0 1 (:unicode "🧟"))
    #(":zombie_man:" 0 1 (:unicode "🧟‍♂️"))
    #(":zombie_woman:" 0 1 (:unicode "🧟‍♀️"))
    #(":zzz:" 0 1 (:unicode "💤"))
    )
  )

(provide 'company-emoji-list)

;;; company-emoji-list.el ends here
